//****************************************************************************
// @Module        Basic Typedefs
// @Filename      basic_Typedefs.h
// @Project       ethernet_board.dav
//----------------------------------------------------------------------------
// @Controller    Infineon XC167CI-16F40
//
// @Compiler      Keil
//
// @Codegenerator 2.4
//
// @Description   This file contains all basic Typedefs
//
//----------------------------------------------------------------------------
// @Date          20.10.2004 15:23:05
//
//****************************************************************************

#ifndef _BASIC_TYPEDEFS_H
#define _BASIC_TYPEDEFS_H

#include "rse_types.h"

#pragma import(__use_no_semihosting)
#pragma import(__use_no_heap)
	
// STDBYRESET == Hibernate Domain Reset || PORESET == Power On Reset
#define POWERON_RESET ((g_poweron_reset))
extern UCHR g_poweron_reset;

#if __ARMCC_VERSION == 5060061
	//#warning "Compiler Version 5.06 Build 61. Bitte ARMCC V501 Build 106 verwenden !!"
#elif __ARMCC_VERSION != 5050106
	#error "Falsche Compiler Version. Bitte ARMCC V501 Build 106 verwenden !!"
#endif

#ifndef MIN
	#define MIN(a,b)    (((a) < (b)) ? (a) : (b))
#endif
#ifndef MAX
	#define MAX(a,b)    (((a) > (b)) ? (a) : (b))
#endif

#define huge


#include <stdio.h>
#include <string.h>
#include <ctype.h>
#include <stdarg.h>

typedef union FLOAT_UNION {
  float _float;
  UCHR  _uchr[4];
} FLOAT_UNION_TYPE;

#if defined(XMC4700_RSECPU)
	#include "XMC4700.h"
#elif defined(XMC4500_RSECPU)
	#include "XMC4500.h"
#else
	#error no cpu defined
#endif

#include "Debug.h"
#include <stdlib.h>
#include "common_functions.h"
  
  // Abfragen der Chip ID der SCU SCU_GENERAL->IDCHIP
  // Der Wert ist ein 32 Bit Register und steht sowohl beim XMC4500 wie auch beim XMC4700 zur Verfgung
  // Definierte Werte fr den XMC4500 laut Datenblatt
  // SCU_GENERAL->IDCHIP == 0x45002  -> XMC4500 Step EES-AA oder Step ES-AA
  // SCU_GENERAL->IDCHIP == 0x45003  -> XMC4500 Step ES-AB oder Step AB
  // SCU_GENERAL->IDCHIP == 0x45004  -> XMC4500 Step AC
  // Definierte Werte fr den XMC4700 laut Datenblatt 
  // SCU_GENERAL->IDCHIP == 0x47001  -> XMC4700 Step AA 
  #define XMCCHIPTYPEMASK 0xFFFFFFF0
  #define XMCCHIPSTEPMASK 0x0000000F
  #define GETXMCCHIPID (SCU_GENERAL->IDCHIP)
  #define XMCISTYPE4500 ((SCU_GENERAL->IDCHIP & XMCCHIPTYPEMASK) == 0x45000)
  #define XMCISTYPE4700 ((SCU_GENERAL->IDCHIP & XMCCHIPTYPEMASK) == 0x47000)  

/*===========================================================================*/
/* Datenstruktur fr die Schnittstellensteuerung                             */
/*===========================================================================*/
typedef struct bufferstruct {           
                                       /* EINLESE-STEUERUNG                  */
  UINT16 inbuf;                          /* FULL = gesperrt(voll) FREE = frei  */
  UINT16 readinpos;                      /* hier wird Eingabebuffer gelesen    */
  UINT16 writinpos;                      /* wird in Eingabebuffer geschrieben  */
                                       
                                       /* AUSGABGE-STEUERUNG                 */
  UINT16 outbuf;                         /* EMPTY = frei WORKING = gesperrt    */
  UCHR *writoutpos;                    /* zeigt auf erstes auszugebendes Byte*/
  UCHR *writoutend;                    /* zeigt auf letztes auszugebend. Byte*/
  UINT16 valid;                          /* 1 -> Zeichen wurde empfangen       */
                                       /* 0 -> kein Zeichen empfangen        */
  UINT16 working_timeout;                /* luft whrend outbuf == WORKING    */
                                       /* wenn > 3 Sekunden outbuf = EMPTY   */

  UINT16 can_dest;                       /* Wird fr RSE_FUNK bentigt         */   
} bufferstruct_type;

typedef struct serdebug_struct {
  UINT16 rxcnt;
	UINT16 txcnt;
	UINT16 uiLostRxChars;				// How many bytes were not read in time
	UINT16 uiRefusedTxPackets;	// How many packets were refused because a transmission was already in progress
} serdebug_struct_type;


#define C1200        '0'
#define C2400        '1'
#define C4800        '2'
#define C9600        '3' 
#define C14400       '4'
#define C19200       '5'
#define C38400       '6'
#define C57600       '7'
#define C115200      '8'
#define C230400      '9'

#define KEINEP       '0'
#define GERADE       '2'
#define UNGERADE     '1'

#define EINSTOPBIT   '0'
#define ZWEISTOPBIT  '1'

#define SIEBENDB     '0'
#define ACHTDB       '1'

#define FULL    0                      /* FULL = Speicher voll               */
#define FREE    1                      /* FREE = Speicher frei               */
#define EMPTY   1                      /* EMPTY   = frei                     */                                                      
#define WORKING 0  

#define NUL    0x00
#define NIL    ((UINT8)0xffu)
#define INIL   ((UINT16)0xffffu)
#define LNIL   ((UINT32)0xffffffffu)

#ifndef TRUE
	#define TRUE  1
#endif
#ifndef FALSE
	#define FALSE 0
#endif


#endif
