#include "basic_typedef.h"
#include "CCU4.h"

extern void NVICEnableCCU40_Irqs (void);

// CCU40 initialisieren
// CCU40 CC40 Timer Mode 8000 Hz fr Sprachwiedergabe
// CCU40 CC41 Timer Mode 1000 Hz fr msecCounter
void vInitCCU4 (void) {
	// Reset fr CCU40 Modul abschalten
	SCU_RESET->PRCLR0 = 0x0004UL;
	
  // CCU40 mit Clock der SCU versorgen
	// Multi Channel Shadow Transfer Request aus
	CCU40->GCTRL = 0x0000UL;
  
  // Disable Idle Mode from CC40
	// Disable Idle Mode from CC41
	// Start Prescaler
	CCU40->GIDLC = 0x0103UL;
	
	// CCU40 Slice CC40 setzen
	/* Program the timer mode */
	// Timer Counter Mode			TCM = 0
  // Single Shot Mode			TSSM = 0
  // Shadow XFER Clear			CLST = 0
  // Prescaler Mode			FPE = 0
  CCU40_CC40->TC = 0x0000UL;
	
  /* Program initial prescaler divider value */
	/* Prescaler = 4, fcc40 = 30 MHz          */
  CCU40_CC40->PSC = 2;
	
	// Period Shadow Register auf 15000 setzen fr 500 usec Takt
	CCU40_CC40->PRS = 15000;
	// Shadow Transfer anfordern
	CCU40->GCSS = 0x0001UL;
	
  // CC40 Interrupt enable Register
	// Enable Period Match Interrupt
	// Disable One Match Interrupt
	// Disable Compare Match while Counting Up Interrupt
	// Disable Compare Match while Counting Down Interrupt
  // Disable Event0 - Event2 Interrupt
  CCU40_CC40->INTE = 0x00001UL;
	
	// CC40 Service Request Selector
	// Period Match Interrupt is forwarded to Service Request Node 0
	CCU40_CC40->SRS = 0x000000UL;
	

	// CCU40 Slice CC41 setzen
	/* Program the timer mode */
	// Timer Counter Mode			TCM = 0
  // Single Shot Mode			TSSM = 0
  // Shadow XFER Clear			CLST = 0
  // Prescaler Mode			FPE = 0
  CCU40_CC41->TC = 0x0000UL;
	
  /* Program initial prescaler divider value */
	/* Prescaler = 4, fcc41 = 30 MHz          */
  CCU40_CC41->PSC = 2;
	
	// Period Shadow Register auf 30000 setzen fr 1 msec Takt
	CCU40_CC41->PRS = 30000;
	// Shadow Transfer anfordern
	CCU40->GCSS = 0x0010UL;
	
  // CC41 Interrupt enable Register
	// Enable Period Match Interrupt
	// Disable One Match Interrupt
	// Disable Compare Match while Counting Up Interrupt
	// Disable Compare Match while Counting Down Interrupt
  // Disable Event0 - Event2 Interrupt
  CCU40_CC41->INTE = 0x00001UL;
	
	// CC41 Service Request Selector
	// Period Match Interrupt is forwarded to Service Request Node 1
	CCU40_CC41->SRS = 0x000001UL;

  NVICEnableCCU40_Irqs();

  // Timer Start
	CCU40_CC40->TCSET =0x0001UL;  // 8kHz (125usec) Timer starten
	CCU40_CC41->TCSET =0x0001UL;  // 1kHz (1msec)   Timer starten
}

UINT32 g_ui32Voice_Counter=0;
void CCU40_0_IRQHandler (void) {
	g_ui32Voice_Counter++;
	CCU40_CC40->SWR = 0x0005UL; // Interrupt Status Clear
}

UINT32 g_ui32MS_Counter=0;
void CCU40_1_IRQHandler (void) {
	CCU40_CC41->SWR = 0x0005UL;
	g_ui32MS_Counter++;
}
