/******************************************************************************
 * @file     DMA.h
 * @brief    Configure DMA of 
 *           for the Infineon XMC4500 Device Series
 *           Verwendung der 12 verfgbaren DMA Kanle
 *           +----------------------------------------------------------------------------------+
 *           + Interrupt	   + INTR Node   + DLR Line  + DMA    +	Channel +	                    +
 *           +----------------------------------------------------------------------------------+
 *           + SPI Bus TX    + USIC0_0     + 0         + GPDMA0 +	0	      *   
 *           + frei          + frei        + 1         + GPDMA0 +	1	      *   
 *           + SPI Bus RX    + USIC0_1     + 2         + GPDMA0 +	2	      * Transfer Finished Intr   
 *           + frei          + frei        + 3         + GPDMA0 +	3	      *   
 *           + frei          + frei        + 4         + GPDMA0 +	4	      *   
 *           + frei          + frei        + 5         + GPDMA0 +	5	      *   
 *           + frei          + frei        + 6         + GPDMA0 +	6	      *   
 *           + frei          + frei        + 7         + GPDMA0 +	7	      *   
 *           + Display TX    + USIC2_0     + 8         + GPDMA1 +	0	      * Transfer Finished Intr  
 *           + Nand Flash M2M+ frei        + 9         + GPDMA1 +	1	      * Transfer Finished Intr 
 *           + frei          + frei        + 10        + GPDMA1 +	2	      *   
 *           + frei          + frei        + 11        + GPDMA1 +	3	      *   
 
 *           +----------------------------------------------------------------------------------+-----------------------------+
 * @version  V1.0.0
 * @date     21. Mai 2015
 *
 ******************************************************************************/

#ifndef _DMA_H_
#define _DMA_H_
// to be called at startup to init GPDMA0
extern void InitGPDMA0 ( void );

#define SPITXSRCNOCHANGE 0
#define SPITXSRCINC      1
// to be called before Transfer to Program DMA
extern void ProgramGPDMASpiTx (volatile void *src, void *dst, volatile unsigned int length, volatile unsigned int srcchange);
// to be called to start Transfer
extern void StartGPDMASpiTx (void);
// to be called before Transfer to Program DMA
#define SPIRXDSTNOCHANGE 0
#define SPIRXDSTINC      1
extern void ProgramGPDMASpiRx (volatile void *src, void *dst, volatile unsigned int length, volatile unsigned dstchange);
// to be called to start Transfer
extern void StartGPDMASpiRx (void);


// to be called at startup to init GPDMA1
extern void InitGPDMA1 ( void );
	
// to be called before Transfer to Program DMA
extern void ProgramGPDMADispTx (volatile void *src, void *dst, volatile unsigned int length);	
// to be called to start Transfer
extern void StartGPDMADispTx  (void);

//for Parameter addrinc in Function ProgramGPDMAM2M
#define DMAADDRNOCHANGE 0
#define DMAADDRSRCINC   1
#define DMAADDRDSTINC   2
#define DMAADDRBOTHINC  3

// uses GPDMA1 Channel 1
// start a M2M DMA Transfer and Wait for Transmission Finished Intr
extern void GPDMAM2MTransfer (volatile void *src, void *dst, volatile unsigned int length, volatile unsigned int addrinc);
#endif
