/******************************************************************************
 * @file     MyMultiplexer.c
 * @brief    Configure EBU of 
 *           for the Infineon XMC4500 Device Series
 * @version  V0.0.1
 * @date     05. Feb 2015
 *
 ******************************************************************************/

/********************** Version History ***************************************
 * V3.0.4, Dec 2014, Added options to configure clock settings
 ******************************************************************************/

/*******************************************************************************
 * HEADER FILES
 *******************************************************************************/

#include "basic_typedef.h"

/*******************************************************************************
 * MACROS
 *******************************************************************************/

/* Define WEAK attribute */
#if !defined(__WEAK)
#if defined ( __CC_ARM )
#define __WEAK __attribute__ ((weak))
#elif defined ( __ICCARM__ )
#define __WEAK __weak
#elif defined ( __GNUC__ )
#define __WEAK __attribute__ ((weak))
#elif defined ( __TASKING__ )
#define __WEAK __attribute__ ((weak))
#endif
#endif



/*******************************************************************************
 * GLOBAL VARIABLES
 *******************************************************************************/

/*******************************************************************************
 * LOCAL FUNCTIONS
 *******************************************************************************/
/*
//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
*/

// Interrupt Priority Register Implementation in XMC4500
// The Interrupt Priority Registers are 8 Bit wide.
// XMC 4500 has implemented 6 Bits (64 Interrupt Priorities) 
// Details to NVIC Priorities see: The definitive Guide to ARM Cortex M3 and ARM Cortex M4 
// +---+---+---+---+---+---+---+---+
// | 7 | 6 | 5 | 4 | 3 | 2 | 1 | 0 |
// +---+---+---+---+---+---+---+---+
// |       implemented     | not i.|
// +---+---+---+---+---+---+---+---+
//
// 
// We use Bit 7-2 as Preempt Priority 
// +---+---+---+---+---+---+---+---+
// | 7 | 6 | 5 | 4 | 3 | 2 | 1 | 0 |
// +---+---+---+---+---+---+---+---+
// |          preempt      | not i.|
// +---+---+---+---+---+---+---+---+
// We use default value of Priority Grouping
//
// Info to Priority Grouping
// +--------------------------------------------+----------------------+
// + Priority Grouping + Preempt Priority Field + Group Priority Field +
// +--------------------------------------------+----------------------+
// | 0 (default)       + Bit [7:1]              + Bit 0                *
// | 1 (used)          + Bit [7:2]              + Bit [1:0]            *
// | 2                 + Bit [7:3]              + Bit [2:0]            *
// | 3                 + Bit [7:4]              + Bit [3:0]            *
// | 4                 + Bit [7:5]              + Bit [4:0]            *
// | 5                 + Bit [7:6]              + Bit [5:0]            *
// | 6                 + Bit [7:7]              + Bit [6:0]            *
// | 7                 + None                   + Bit [7:0]            *
// +--------------------------------------------+----------------------+
#define PRIORITY(p) (((63-p))) // Shifting is done by NVIC_SetPriority !
/*
// <h> CAN Interrupts
*/

/*
// ---------------- CAN Interrupt Node 0 ------------------------------------------------
// <h> CAN Interrupt 0  Node 2 (Busrechner) RX Interrupt
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define CANNODE0PRIORITY (45U)
// 		</h>

/*
// ---------------- CAN Interrupt Node 1 ------------------------------------------------
// <h> CAN Interrupt 1  Node 2 (Busrechner) TX Interrupt
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define CANNODE1PRIORITY (42U)
// 		</h>

/*
// ---------------- CAN Interrupt Node 2 ------------------------------------------------
// <h> CAN Interrupt 2  Node 1 (TAS Vernetzung) RX Interrupt
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define CANNODE2PRIORITY (44U)
// 		</h>

/*
// ---------------- CAN Interrupt Node 3 ------------------------------------------------
// <h> CAN Interrupt 1  Node 1 (TAS Vernetzung) TX Interrupt
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define CANNODE3PRIORITY (42U)
// 		</h>

/*
// ---------------- CAN Interrupt Node 3 ------------------------------------------------
// <h> CAN Interrupt 4  Node 0 (CANOPEN) RX Interrupt
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define CANNODE4PRIORITY (43U)
// 		</h>

/*
// ---------------- CAN Interrupt Node 5 ------------------------------------------------
// <h> CAN Interrupt 5  Node 0 (CANOPEN) TX Interrupt
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define CANNODE5PRIORITY (42U)
// 		</h>
// 		</h>

/*
// <h> USIC0 Interrupts
*/

/*
// ---------------- USIC0 Interrupt Node 0 ------------------------------------------------
// <h> USIC0 Interrupt 2 U0C0 RX Interrupt (SPI Memory) 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  USIC0INTR0 (47U)
// 		</h>

/*
// ---------------- USIC0 Interrupt Node 1 ------------------------------------------------
// <h> USIC0 Interrupt 1 U0C0 TX Interrupt (SPI_Memory) 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  USIC0INTR1 (46U)
// 		</h>

/*
// ---------------- USIC0 Interrupt Node 2 ------------------------------------------------
// <h> USIC0 Interrupt 2 U0C1 RX Interrupt (COM4 RS232) 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  USIC0INTR2 (40U)
// 		</h>

/*
// ---------------- USIC0 Interrupt Node 3 ------------------------------------------------
// <h> USIC0 Interrupt 3 U0C1 TX Interrupt (COM4 RS232) 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  USIC0INTR3 (39U)

// 		</h>

// 		</h>





/*
// <h> USIC1 Interrupts
*/

/*
// ---------------- USIC1 Interrupt Node 0 ------------------------------------------------
// <h> USIC1 Interrupt 0 U1C1 RX Interrupt (USB/RS232 Wartung) 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  USIC1INTR0 (40U)
// 		</h>

/*
// ---------------- USIC1 Interrupt Node 1 ------------------------------------------------
// <h> USIC1 Interrupt 1 U0C0 TX Interrupt (USB/RS232 Wartung) 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  USIC1INTR1 (39U)
// 		</h>

// 		</h>

/*
// <h> USIC2 Interrupts
*/

/*
// ---------------- USIC2 Interrupt Node 0 ------------------------------------------------
// <h> USIC2 Interrupt 0 U2C0 Transmit Shift Interrupt (SPI Display) 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  USIC2INTR0 (40U)
// 		</h>

/*
// ---------------- USIC2 Interrupt Node 1 ------------------------------------------------
// <h> USIC2 Interrupt 1 U2C0 Alternate Recieve Buffer Interrupt SPI Display
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  USIC2INTR1 (39U)
// 		</h>

/*
// ---------------- USIC2 Interrupt Node 2 ------------------------------------------------
// <h> USIC2 Interrupt 2 U2C1 U2C1 Standard RX Buffer Interrupt (COM2 RS485) 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  USIC2INTR2 (40U)
// 		</h>

/*
// ---------------- USIC2 Interrupt Node 3 ------------------------------------------------
// <h> USIC2 Interrupt 3 U2C1 TX Frame Finished Interrupt (COM2 RS485)
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  USIC2INTR3 (39U)
// 		</h>

// 		</h>

/*
// <h> ERU Interrupts
*/

/*
// ---------------- ERU0 Interrupt Node 1 ------------------------------------------------
// <h> ERU0 Interrupt Node 1 (Tastatur) 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  ERU0INTR1 (20U)
// 		</h>

/*
// ---------------- ERU0 Interrupt Node 2 (Netzausfall)  ------------------------------------------------
// <h> ERU0 Interrupt Node 2 (Netzausfall) 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  ERU0INTR2 (60U)
// 		</h>

// 		</h>

/*
// <h> CCU40 Interrupts
*/

/*
// ---------------- CCU40 Interrupt Node 0 ------------------------------------------------
// <h> CCU40 Interrupt 0 (Sprachwiedergabe)
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  CCU40INTR0 (50U)
// 		</h>

/*
// ---------------- CCU40 Interrupt Node 1 ------------------------------------------------
// <h> CCU40 Interrupt 1 (msec Counter)
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  CCU40INTR1 (49U)
// 		</h>

// 		</h>

/*
// <h> DMA Interrupts
*/

/*
// ---------------- DMA0 Interrupt Node 0 ------------------------------------------------
// <h> DMA0 Interrupt 0 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  DMA0INTR0 (5U)
// 		</h>

/*
// ---------------- DMA1 Interrupt Node 0 ------------------------------------------------
// <h> DMA1 Interrupt 0 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  DMA1INTR0 (5U)
// 		</h>

// 		</h>

/*
// <h> Ethernet Interrupt
*/

/*
// ---------------- Ethernet Interrupt Node  ------------------------------------------------
// <h> Ethernet Interrupt 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  ETHINTR (41U)
// 		</h>

// 		</h>

/*
// <h> SCU Interrupt
*/

/*
// ---------------- SCU Interrupt Node  ------------------------------------------------
// <h> SCU0 Interrupt 
//    <o> Preemptive Priority 
//       <2=> 2
//       <3=> 3
//       <4=> 4
//       <5=> 5
//       <6=> 6
//       <7=> 7
//       <8=> 8
//       <9=> 9
//       <10=> 10
//       <11=> 11
//       <12=> 12
//       <13=> 13
//       <14=> 14
//       <15=> 15
//       <16=> 16
//       <17=> 17 
//       <18=> 18
//       <19=> 19
//       <20=> 20
//       <21=> 21
//       <22=> 22
//       <23=> 23
//       <24=> 24
//       <25=> 25
//       <26=> 26
//       <27=> 27
//       <28=> 28
//       <29=> 29
//       <30=> 30
//       <31=> 31
//       <32=> 32
//       <33=> 33
//       <34=> 34
//       <35=> 35
//       <36=> 36
//       <37=> 37
//       <38=> 38
//       <39=> 39
//       <40=> 40
//       <41=> 41
//       <42=> 42
//       <43=> 43
//       <44=> 44
//       <45=> 45
//       <46=> 46
//       <47=> 47
//       <48=> 48
//       <49=> 49
//       <50=> 50
//       <51=> 51 
//       <52=> 52
//       <53=> 53
//       <54=> 54
//       <55=> 55
//       <56=> 56
//       <57=> 57
//       <58=> 58
//       <59=> 59
//       <60=> 60
//       <61=> 61
//       <62=> 62
//       <63=> 63
//       <i> (2 is lowest, 63 is highest, 0 and 1 reserved for RTOS)
*/
#define  SCU0INTR (60U)
// 		</h>

// 		</h>


/*
//-------- <<< end of configuration section >>> ------------------
*/

/*******************************************************************************
 * API IMPLEMENTATION
 *******************************************************************************/
/*
*/

UINT32 g_ui32UnknownIRQs = 0;

/*
// Interrupt Handler
*/
//#define  ERU0_1_IRQn 2    /*!<   wird Tastaturinterrupt                                              */
//#define  ERU0_2_IRQn 3    /*!<   wird Netzausfallinterrupt                                           */
/*
// Tastaturinterrupt extern
*/
// definiert in Display.c
void ERU0_1_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

void ERU0_2_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

/*
// CAN IRQ Handler
*/
//#define CAN0_0_IRQn 76         /*!<  mit GPDMA verbunden Verwendung festlegen                                                           */
//#define CAN0_1_IRQn 77         /*!<  mit GPDMA verbunden Verwendung festlegen                                                           */
//#define CAN0_2_IRQn 78         /*!<  mit GPDMA verbunden Verwendung festlegen                                                           */
//#define CAN0_3_IRQn 79         /*!<  mit GPDMA verbunden Verwendung festlegen                                                           */
//#define CAN0_4_IRQn 80         /*!<  Verwendung festlegen                                                           */
//#define CAN0_5_IRQn 81         /*!<  Verwendung festlegen                                                           */
//#define CAN0_6_IRQn 82         /*!<  Verwendung festlegen                                                           */
//#define CAN0_7_IRQn 83         /*!<  Verwendung festlegen                                                           */

// in CAN2_Busrechner.c definiert
// Node 2 RX Interrupt
void CAN0_0_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}
// Node 2 TX Interrupt
void CAN0_1_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

// in CAN1_Canopen.c definiert
// Node 1 RX Interrupt
void CAN0_2_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}
// Node 1 TX Interrupt
void CAN0_3_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

// in CAN0_RSE.c definiert
// Node 0 RX Interrupt
void CAN0_4_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}
// Node 0 TX Interrupt
void CAN0_5_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

void CAN0_6_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

void CAN0_7_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

//#define  USIC0_0_IRQn 84              /*!<  mit GPDMA verbunden, U0C0 Transmit Shift Interrupt / Level 15        */
//#define  USIC0_1_IRQn 85              /*!<  mit GPDMA verbunden, U0C0 Alternate Receive Interrupt / Level 15     */
//#define  USIC0_2_IRQn 86              /*!<  U0C1 Standard RX Buffer Interrupt  / Level 5                         */
//#define  USIC0_3_IRQn 87              /*!<  U0C1 Transmit Shift Interrupt      / Level 4                         */
//#define  USIC0_4_IRQn 88              /*!<  88  USIC0_4                                                          */
//#define  USIC0_5_IRQn 89              /*!<  89  USIC0_5                                                          */

// in U0C1_COM4.c definiert
void USIC0_2_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   
void USIC0_3_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

void USIC0_4_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   

void USIC0_5_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   


/*
*/
//#define  USIC1_0_IRQn 90              /*!<  mit GPDMA verbunden U1C1 Standard RX Buffer Interrupt  / Level 5                         */
//#define  USIC1_1_IRQn 91              /*!<  mit GPDMA verbunden U1C1 Transmit Shift Interrupt      / Level 4                         */
//#define  USIC1_2_IRQn 92              /*!<  92  USIC1_2                                                          */
//#define  USIC1_3_IRQn 93              /*!<  93  USIC1_3                                                          */
//#define  USIC1_4_IRQn 94              /*!<  94  USIC1_4                                                          */
//#define  USIC1_5_IRQn 95              /*!<  95  USIC1_5                                                          */

// in U1C1_Com1.c definiert
void USIC1_0_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   
void USIC1_1_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}	

void USIC1_2_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   

void USIC1_3_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

void USIC1_4_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   

void USIC1_5_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   

//#define  USIC2_0_IRQn 96              /*!<  mit GPDMA verbunden, U2C0 Transmit Shift Interrupt / Level 15        */
//#define  USIC2_1_IRQn 97              /*!<  mit GPDMA verbunden, U2C0 Alternate Receive Interrupt / Level 15     */
//#define  USIC2_2_IRQn 98              /*!<  U2C1 Standard RX Buffer Interrupt                    / Level 5       */
//#define  USIC2_3_IRQn 99              /*!<  U2C1 ASC Protocol Interrupt Frame Finish Interrupt   / Level 4       */
//#define  USIC2_4_IRQn 100             /*!<  100  USIC2_4                                                         */
//#define  USIC2_5_IRQn 101             /*!<  101  USIC2_5                                                         */
void USIC2_0_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   
void USIC2_1_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}	

//in U2C1_COM2 definiert 
void USIC2_2_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   
void USIC2_3_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

void USIC2_4_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   

void USIC2_5_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}   

/*
// CCU 40 IRQ Handler
*/
// CCU40_0_IRQHandler 44
// CCU40_1_IRQHandler 45
// CCU40_2_IRQHandler 46
// CCU40_3_IRQHandler 47

void CCU40_2_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

void CCU40_3_IRQHandler (void) {
	g_ui32UnknownIRQs++;
}

/*
// DMA IRQ Handler
*/
// GPDMA1_0_IRQHandler
void GPDMA1_0_IRQHandler () {
	g_ui32UnknownIRQs++;
}

__STATIC_INLINE void XMC_SCU_INTERRUPT_ClearEventStatus(const uint32_t event)
{
  SCU_INTERRUPT->SRCLR |= (uint32_t)event;
}

unsigned int g_ui32PeriodicRtcEvents = 0;
void SCU_0_IRQHandler()
{
	// manual page 474:
	// #warning When servicing an SCU service request, make sure that all related request flags 
	// are cleared after the identified request has been handled
	// see also page 475 - table 11-1
	
  g_ui32PeriodicRtcEvents++;
  if ((g_ui32PeriodicRtcEvents%2) == 0)  {  
    PORT1->OUT |= 0x8000;                      // Set P1.15
  } 
  else {
    PORT1->OUT &= ~(0x8000);                   // Reset P1.15
  }
  XMC_SCU_INTERRUPT_ClearEventStatus(0x02);
}

// Set Priority Grouping in System Init before RTOS is started
void NVIC_SystemInit(void) {
  // Set thr Priority Grouping
  NVIC_SetPriorityGrouping(1);
}

void NVICInit(void)
{	
	// CAN Interrupts
	NVIC_SetPriority(CAN0_0_IRQn, PRIORITY(CANNODE0PRIORITY));
	NVIC_SetPriority(CAN0_1_IRQn, PRIORITY(CANNODE1PRIORITY));	
	NVIC_SetPriority(CAN0_2_IRQn, PRIORITY(CANNODE2PRIORITY));
	NVIC_SetPriority(CAN0_3_IRQn, PRIORITY(CANNODE3PRIORITY));	
	NVIC_SetPriority(CAN0_4_IRQn, PRIORITY(CANNODE4PRIORITY));
	NVIC_SetPriority(CAN0_5_IRQn, PRIORITY(CANNODE5PRIORITY));

	// RX und TX Interrupt U0C1_COM4 RS232 Kopplung
	NVIC_SetPriority(USIC0_2_IRQn, PRIORITY(USIC0INTR2));
	NVIC_SetPriority(USIC0_3_IRQn, PRIORITY(USIC0INTR3));

	// RX und TX Interrupt U0C0_SPI_Memory 
	NVIC_SetPriority(USIC0_0_IRQn, PRIORITY(USIC0INTR0));
	NVIC_SetPriority(USIC0_1_IRQn, PRIORITY(USIC0INTR1));
	
	// RX und TX Interrupt U1C1_COM1_RS232_USB_Wartung 
	NVIC_SetPriority(USIC1_0_IRQn, PRIORITY(USIC1INTR0));
	NVIC_SetPriority(USIC1_1_IRQn, PRIORITY(USIC1INTR1));	

	// RX und TX Interrupt U2C0_SPI_Display 
	NVIC_SetPriority(USIC2_0_IRQn, PRIORITY(USIC2INTR0));
	NVIC_SetPriority(USIC2_1_IRQn, PRIORITY(USIC2INTR1));	
	
	// RX und TX Interrupt U2C1_COM2 
	NVIC_SetPriority(USIC2_2_IRQn, PRIORITY(USIC2INTR2));
	NVIC_SetPriority(USIC2_3_IRQn, PRIORITY(USIC2INTR3));	

  // Tastatur und Netzausfall Interrupt
	NVIC_SetPriority(ERU0_1_IRQn, PRIORITY(ERU0INTR1)); // Tastaturinterrupt
	NVIC_SetPriority(ERU0_2_IRQn, PRIORITY(ERU0INTR2)); // Netzausfallinterrupt

	// Interrupt fr Timer CCU40
	NVIC_SetPriority(CCU40_0_IRQn, PRIORITY(CCU40INTR0));
	NVIC_SetPriority(CCU40_1_IRQn, PRIORITY(CCU40INTR1));
	
	// Interrupt fr DMA 
	NVIC_SetPriority(GPDMA0_0_IRQn, PRIORITY(DMA0INTR0));
	NVIC_SetPriority(GPDMA1_0_IRQn, PRIORITY(DMA1INTR0));

  // Interrupt fr Ethernet 
  NVIC_SetPriority(ETH0_0_IRQn, PRIORITY(ETHINTR));

  // Interrupt fr Ausgabe Sekundentakt von der Uhr
  NVIC_SetPriority(SCU_0_IRQn, PRIORITY(SCU0INTR));  

}

void NVICEnableCAN0Irqs (void) {
  NVIC_EnableIRQ(CAN0_4_IRQn);	
  NVIC_EnableIRQ(CAN0_5_IRQn);
}

void NVICEnableCAN1Irqs (void) {
  NVIC_EnableIRQ(CAN0_2_IRQn);
  NVIC_EnableIRQ(CAN0_3_IRQn);
}

void NVICEnableCAN2Irqs (void) {
  NVIC_EnableIRQ(CAN0_0_IRQn);
  NVIC_EnableIRQ(CAN0_1_IRQn);
}

void NVICEnableUSIC0_CH1_Irqs (void) {
  NVIC_EnableIRQ(USIC0_2_IRQn);
  NVIC_EnableIRQ(USIC0_3_IRQn);
}

void NVICDisableUSIC0_CH1_Irqs (void) {
  NVIC_DisableIRQ(USIC0_2_IRQn);
  NVIC_DisableIRQ(USIC0_3_IRQn);
}

void NVICEnableUSIC0_CH0_Irqs (void) {
  NVIC_EnableIRQ(USIC0_0_IRQn);
  NVIC_EnableIRQ(USIC0_1_IRQn);
}

void NVICEnableUSIC1_CH1_Irqs (void) {
  NVIC_EnableIRQ(USIC1_0_IRQn);
  NVIC_EnableIRQ(USIC1_1_IRQn);
}

void NVICDisableUSIC1_CH1_Irqs (void) {
  NVIC_DisableIRQ(USIC1_0_IRQn);
  NVIC_DisableIRQ(USIC1_1_IRQn);
}

void NVICEnableUSIC2_CH0_Irqs (void) {
  NVIC_EnableIRQ(USIC2_0_IRQn);
  NVIC_EnableIRQ(USIC2_1_IRQn);
}

void NVICEnableTastaturIrq (void) {
  NVIC_EnableIRQ(ERU0_1_IRQn);
}

void NVICEnableNetzausfallIrq (void) {
  NVIC_EnableIRQ(ERU0_2_IRQn);
}

void NVICEnableUSIC2_CH1_Irqs (void) {
  NVIC_EnableIRQ(USIC2_2_IRQn);
  NVIC_EnableIRQ(USIC2_3_IRQn);
}

void NVICDisableUSIC2_CH1_Irqs (void) {
  NVIC_DisableIRQ(USIC2_2_IRQn);
  NVIC_DisableIRQ(USIC2_3_IRQn);
}

void NVICEnableCCU40_Irqs (void) {
  NVIC_EnableIRQ(CCU40_0_IRQn);
	NVIC_EnableIRQ(CCU40_1_IRQn);
}

void NVICEnableDMA0_Irq (void) {
  NVIC_EnableIRQ(GPDMA0_0_IRQn);
}

void NVICEnableDMA1_Irq (void) {
  NVIC_EnableIRQ(GPDMA1_0_IRQn);
}

void NVICEnableSCU0_Irq (void) {
  NVIC_EnableIRQ(SCU_0_IRQn);
}
