/******************************************************************************
 * @file     MyMultiplexer.c
 * @brief    Configure EBU of 
 *           for the Infineon XMC4500 Device Series
 * @version  V0.0.1
 * @date     05. Feb 2015
 *
 ******************************************************************************/

/********************** Version History ***************************************
 * V3.0.4, Dec 2014, Added options to configure clock settings
 ******************************************************************************/

/*******************************************************************************
 * HEADER FILES
 *******************************************************************************/

#include "basic_typedef.h"
/*******************************************************************************
 * MACROS
 *******************************************************************************/

/* Define WEAK attribute */
#if !defined(__WEAK)
#if defined ( __CC_ARM )
#define __WEAK __attribute__ ((weak))
#elif defined ( __ICCARM__ )
#define __WEAK __weak
#elif defined ( __GNUC__ )
#define __WEAK __attribute__ ((weak))
#elif defined ( __TASKING__ )
#define __WEAK __attribute__ ((weak))
#endif
#endif



/*******************************************************************************
 * GLOBAL VARIABLES
 *******************************************************************************/

/*******************************************************************************
 * LOCAL FUNCTIONS
 *******************************************************************************/
/*
//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
*/

/*
// <h> CAN0 (CAN nach auen zum Vernetzen von TAS)
*/

/*
// ---------------- CAN0 --------------------------------------------------
//    <o> Receive Input CAN0
//       <0x00=> P1.5 (RXDC0A)
//       <0x01=> P14.3 (RXDC0B)
//       <0x02=> P3.12 (RXDC0C)
//    <i> Defines Input Configuration of CON0RX
*/
#define CAN0RXSEL (2U)
// 		</h>

/*
// <h> CAN1 (CANOPEN Schnittstelle)
*/

/*
//    <o> Receive Input CAN1
//       <0x00=> P2.6 (RXDC1A)
//       <0x01=> P3.11 (RXDC1B)
//       <0x02=> P1.13 (RXDC1C)
//       <0x03=> P1.4 (RXDC1D)
//       <0x05=> CAN0INS (RXD1F)
//    <i> Defines Input Configuration of CON1RX
*/
#define  CAN1RXSEL (0U)
// 		</h>

/*
// <h> CAN2 ( Vernetzung zum Busrechner )
*/

/*
//    <o> Receive Input CAN2
//       <0x00=> P1.8 (RXDC2A)
//       <0x01=> P3.8 (RXDC2B)
//       <0x02=> P4.6 (RXDC2C)
//       <0x05=> CAN0INS (RXDC2F)
//    <i> Defines Input Configuration of CON2RX
*/
#define  CAN2RXSEL (1U)
// 		</h>

/*
// <h> USIC0C0 (SPI Bus fr Speicher)
*/

/*
//    <o> Receive Input MRST (Master Receive Slave Transmit)
//       <0x00=> P1.5  (DX0BA)
//       <0x01=> P1.4  (DX0B)
//       <0x02=> P4.7  (DX0C)
//       <0x03=> P5.0  (DX0D)
//       <0x05=> XTAL1 (DX0F)
//       <0x06=> Loopback (DX0G)

//    <i> Defines Input Configuration of Receive Input SPI FRAM
*/
#define  U0C0DX0CR (0U)
// 		</h>

/*
// <h> USIC0C1 (Async RS232 Kopplung)
*/

/*
//    <o> Receive Input RXD
//       <0x00=> P2.2  (DX0BA)
//       <0x01=> P2.5  (DX0B)
//       <0x02=> P6.3  (DX0C)
//       <0x03=> P3.13 (DX0D)
//       <0x04=> P4.0  (DX0E)
//       <0x05=> XTAL1 (DX0F)
//       <0x06=> Loopback (DX0G)

//    <i> Defines Input Configuration of RXD RS232 Kopplung
*/
#define  U0C1DX0CR (2U)
// 		</h>

/*
// <h> USIC1C1 (Async RS232 Wartung)
*/

/*
//    <o> Receive Input RXD
//       <0x00=> P3.15  (DX0BA)
//       <0x01=> P3.14  (DX0B)
//       <0x02=> P4.2   (DX0C)
//       <0x03=> P0.0   (DX0D)
//       <0x04=> CAN1INS(DX0E)
//       <0x05=> XTAL1 (DX0F)
//       <0x06=> Loopback (DX0G)

//    <i> Defines Input Configuration of RXD Wartung USB
*/
#define  U1C1DX0CR (1U)
// 		</h>

/*
// <h> USIC2C0 (SPI Bus fr Display)
*/

/*
//    <o> Receive Input MRST (Master Receive Slave Transmit)
//       <0x00=> P5.1  (DX0BA)
//       <0x01=> P5.0  (DX0B)
//       <0x02=> P3.7  (DX0C)
//       <0x05=> XTAL1 (DX0F)
//       <0x06=> Loopback (DX0G)

//    <i> Defines Input Configuration of Receive Input SPI Display (not used)
*/
#define  U2C0DX0CR (6U)
// 		</h>

/*
// <h> USIC2C1 (Async RS422 fr Kopplung)
*/

/*
//    <o> Receive Input RXD
//       <0x00=> P3.5  (DX0A)
//       <0x01=> P3.4  (DX0B)
//       <0x02=> P4.0  (DX0C)
//       <0x03=> P3.12  (DX0D)
//       <0x04=> CAN1INS(DX0E)
//       <0x05=> XTAL1 (DX0F)
//       <0x06=> Loopback (DX0G)

//    <i> Defines Input Configuration of RXD RS485 Kopplung
*/
#define  U2C1DX0CR (1U)
// 		</h>

/*
// <h> Ethernet (ETH0 RMII)
*/

/*
//    <o> Receive Input RXD0
//       <0x00=> P2.2  (RXD0A)
//       <0x01=> P0.2  (RXD0B)
//       <0x02=> P14.8  (RXD0C)
//       <0x03=> P5.0  (RXD0D)

//    <i> Defines Input Configuration of RXD0 ETH0
*/
#define  ETH0RXD0CR (2U)

/*
//    <o> Receive Input RXD1
//       <0x00=> P2.3  (RXD1A)
//       <0x01=> P0.3  (RXD1B)
//       <0x02=> P14.9  (RXD1C)
//       <0x03=> P5.1  (RXD1D)

//    <i> Defines Input Configuration of RXD1 ETH0
*/
#define  ETH0RXD1CR (2U)

/*
//    <o> Clock Input CLK_RMII
//       <0x00=> P2.1  (RMIIA)
//       <0x01=> P0.0  (RMIIB)
//       <0x02=> P15.8  (RMIIC)
//       <0x03=> P6.5  (RMIID)

//    <i> Defines Input Configuration of CLK_RMII ETH0
*/
#define  ETH0CLKRMIICR (2U)

/*
//    <o> Input CRS_DV
//       <0x00=> P2.5  (CRS_DVA)
//       <0x01=> P0.1  (CRS_DVB)
//       <0x02=> P15.9  (CRS_DVC)
//       <0x03=> P5.2  (CRS_DVD)

//    <i> Defines Input Configuration of CRS_DV ETH0
*/
#define  ETH0CRSDVCR (2U)

/*
//    <o> Input RXER
//       <0x00=> P2.4  (RXERA)
//       <0x01=> P0.11  (RXERB)
//       <0x02=> (RXERC)
//       <0x03=> P5.3  (RXERD)

//    <i> Defines Input Configuration of RXER ETH0
*/
#define  ETH0RXERCR (1U)

/*
//    <o> Input MDI
//       <0x00=> P0.9  (MDIA)
//       <0x01=> P2.0  (MDIB)
//       <0x02=> P1.11  (MDIC)
//       <0x03=> (MDID)

//    <i> Defines Input Configuration of RXER ETH0
*/
#define  ETH0MDICR (2U)

// 		</h>

/*
//-------- <<< end of configuration section >>> ------------------
*/

/*******************************************************************************
 * API IMPLEMENTATION
 *******************************************************************************/


// Kopplung RS232 Initialisieren (COM4)
void USIC0C1_ASC_vInit(UCHR baudrate_in, UCHR datenbits_in, UCHR paritaet_in, UCHR stopbits_in)
{
  UINT32 step;  // Fr Baudrate
	UINT32 pdiv;  // Fr Baudrate
  UINT32 pctq;  // Fr Baudrate
  UINT32 dctq;	// Fr Baudrate
	UINT32 datenbits; // Fr Datenbits 7, 8
	UINT32 stopbits;  // Fr Anzahl Stopbits 1, 2
	UINT32 parity;    // 0..aus, 1..not allowed, 2..Even, 3..Odd  Check Chip Bug USIC_AI.007
	
	//   -----------------------------------------------------------------------
  //   Initialization of USIC Peripherals:
  //   -----------------------------------------------------------------------

  ///  - USIC0 module clock = 120,00 MHz 

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C1 Kernel State Configuration:
  ///  -----------------------------------------------------------------------

  USIC0_CH1->KSCFG     =  0x0003UL;      // Set "Module Enable" in kernel state configuration 
                                       // register 
	while ((USIC0_CH1->KSCFG & 0x0001UL) == 0U);

  ///  -----------------------------------------------------------------------
  ///  Configuration of the USIC Channel Control Register (Mode & Interrupts):
  ///  -----------------------------------------------------------------------
  /// - The USIC channel is disabled

  USIC0_CH1->CCR       =  0x0000UL;      // load USIC channel control register

  ///  -----------------------------------------------------------------------
  ///  U0C1 ASC is configured for Full-Duplex Operation Mode:
  ///  -----------------------------------------------------------------------

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C1 Fractional Divider:
  ///  -----------------------------------------------------------------------
	///  Siehe Excel Sheet Baudratenberechnung fr USIC
  ///  - Baudraten fr Module clock = 120,00 MHz 
  ///  -   1200, STEP = 0x0020,  PDIV = 0x63, PCTQ = 0x01, DCTQ = 0x0f 
  ///  -   2400, STEP = 0x0041,  PDIV = 0x63, PCTQ = 0x01, DCTQ = 0x0f 
  ///  -   4800, STEP = 0x0082,  PDIV = 0x63, PCTQ = 0x01, DCTQ = 0x0f 
  ///  -   9600, STEP = 0x020B,  PDIV = 0xC7, PCTQ = 0x01, DCTQ = 0x0f 
  ///  -  14400, STEP = 0x0188,  PDIV = 0x63, PCTQ = 0x01, DCTQ = 0x0f 
  ///  -  19200, STEP = 0x020B,  PDIV = 0x63, PCTQ = 0x01, DCTQ = 0x0f 
  ///  -  38400, STEP = 0x020B,  PDIV = 0x31, PCTQ = 0x01, DCTQ = 0x0f 
  ///  -  57600, STEP = 0x0331,  PDIV = 0x32, PCTQ = 0x01, DCTQ = 0x0f 
  ///  - 115200, STEP = 0x0331,  PDIV = 0x19, PCTQ = 0x01, DCTQ = 0x0f 

	pctq = 0x01;
	dctq = 0x0f;
	switch(baudrate_in)
	{
		case C1200:
			step = 0x0020;
			pdiv = 0x63;
			break;
		case C2400:
			step = 0x0041;
			pdiv = 0x63;
			break;
		case C4800:
			step = 0x0082;
			pdiv = 0x63;
			break;
		case C9600:
		default:
			step = 0x020BUL;
			pdiv = 0x00C7UL;
			break;
		case C14400:
			step = 0x0188;
			pdiv = 0x63;
			break;
		case C19200:
			step = 0x020B;
			pdiv = 0x63;
			break;
		case C38400:
			step = 0x020B;
			pdiv = 0x31;
			break;
		case C57600:
			step = 0x0331;
			pdiv = 0x32;
			break;
		case C115200:
			step = 0x0331;
			pdiv = 0x19;
			break;
	}


  USIC0_CH1->FDR  =  ((0x8000UL) |
	                    (step    ) ); 

  USIC0_CH1->BRG = ((pdiv << 16) |
	                  (dctq << 10) |
										(pctq <<  8));  

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C1 Input Control Register 0:
  ///  -----------------------------------------------------------------------
  ///  - The data input  P6.3  (DX0C) is selected for pin 

  USIC0_CH1->DX0CR = U0C1DX0CR;

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C1 Interrupt Node Pointer Register:
  ///  -----------------------------------------------------------------------
  ///  Fr RS232 Transmit Shift Interrupt -> TXD Interrupt -> Interrupt SR3 qird verwendet

  USIC0_CH1->INPR  =  0x00003UL; // Fr RS232
	

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C1 Shift Control:
  ///  -----------------------------------------------------------------------
  ///  - Transmit/Receive LSB first is selected
  ///  - Transmission Mode (TRM) = 1
  ///  - Passive Data Level (PDL) = 1
  ///  - Word Length (WLE) = 7
  ///  - Frame Length (FLE) = 7
	switch(datenbits_in) {
		case SIEBENDB:
			datenbits = 7UL;  // Mgliche Werte 7UL und 8 UL
		case ACHTDB:
		default:
			datenbits = 8UL;  // Mgliche Werte 7UL und 8 UL
			break;
	}
  USIC0_CH1->SCTR =  (((datenbits-1) << 16) |
                      ((datenbits-1) << 24) |  
	                     (0x0102UL) );

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C1 Transmit Control/Status Register:
  ///  -----------------------------------------------------------------------
  ///  - TBUF Data Enable (TDEN) = 1
  ///  - TBUF Data Single Shot Mode (TDSSM) = 1
  
	USIC0_CH1->TCSR = 0x0500UL;

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C1 Protocol Control Register:
  ///  -----------------------------------------------------------------------
  ///  - Sample Mode (SMD) = 1
  ///  - 1 Stop bit is selected
  ///  - Sample Point (SP) = 7
  ///  - Pulse Length (PL) = 0
	switch(stopbits_in) {
		case EINSTOPBIT:
		default:
			stopbits = 1;  // Erlaubte Werte 1, 2
			break;
		case ZWEISTOPBIT:
			stopbits = 2;  // Erlaubte Werte 1, 2
			break;
	}
  USIC0_CH1->PCR_ASCMode = (((stopbits-1) << 1) |
	                           (0x0701UL) );
  
  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C1 Protocol Status Register:
  ///  -----------------------------------------------------------------------
  ///  - TBIF is set to simplify polling

  USIC0_CH1->PSR_ASCMode |=  0x2000;      // load U0C1 protocol status register

  ///  -----------------------------------------------------------------------
  ///  Configuration of U0C1 FIFO:
  ///  -----------------------------------------------------------------------
  ///  -----------------------------------------------------------------------
  ///  Configuration of U0C1 Transmitter Buffer Conrol Register:
  ///  -----------------------------------------------------------------------
  ///  - Transmit FIFO buffer is disabled
  ///  -----------------------------------------------------------------------
  ///  Configuration of U0C1 Receiver Buffer Conrol Register:
  ///  -----------------------------------------------------------------------
  ///  - Receive FIFO buffer contains 32 entries
  ///  - Receive FIFO buffer starts at Data Pointer 0
  ///  - Limit for receive FIFO interrupt generation is 0
  ///  - Filling level mode is selected
  ///  - Standard Receive buffer interrupt is enabled
  ///  - Interrupt Node Pointer for Standard Receive Buffer Interrupt is 2 (SR2 is aktivated)
	USIC0_CH1->RBCTR = 0x55020000UL;

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C1 Channel Control Register (Mode & Interrupts):
  ///  -----------------------------------------------------------------------
  ///  - ASC (SCI, UART) Protocol is selected 
  ///  - The parity generation is disabled
  ///  - Transmit shift interrupt is enabled
	switch(paritaet_in) {
		case KEINEP:
		default:
			parity = 0;    // 0..aus, 1..not allowed, 2..Even, 3..Odd  Check Chip Bug USIC_AI.007
			break;
		case GERADE:
			parity = 2;    // 0..aus, 1..not allowed, 2..Even, 3..Odd  Check Chip Bug USIC_AI.007
			break;
		case UNGERADE:
			parity = 3;    // 0..aus, 1..not allowed, 2..Even, 3..Odd  Check Chip Bug USIC_AI.007
			break;
	}
  USIC0_CH1->CCR       = ((parity << 8) | 
	                        (0x1002) );      // load U0C1 channel control register


} //  End of function U0C1_ASC_vInit




// SPI Bus fr Speicher initialisieren
void U0C0_SSC_vInit(void)
{

  //   -----------------------------------------------------------------------
  //   Initialization of USIC Peripherals:
  //   -----------------------------------------------------------------------
  ///  - USIC0 module clock = 120,00 MHz

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Kernel State Configuration:
  ///  -----------------------------------------------------------------------

  USIC0_CH0->KSCFG     =  0x0003UL;    // Set "Module Enable" in kernel state configuration 
                                       // register 
	while ((USIC0_CH0->KSCFG & 0x0001UL) == 0U);

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Channel Control Register (Mode & Interrupts):
  ///  -----------------------------------------------------------------------
  /// - The USIC channel is disabled
  /// - The parity generation is disabled

  USIC0_CH0->CCR       =  0x0000;      // load U0C0 channel control register

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Fractional Divider:
  ///  -----------------------------------------------------------------------
  ///  - The Fractional divider is selected
  ///  - The step value STEP = 580

  USIC0_CH0->FDR      =  0x8243UL;      // load U2C1 fractional divider register

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Baudrate Generator:
  ///  -----------------------------------------------------------------------
  ///  - The selected BaudRate is 2,000 Mbaud
  ///  - The PreDivider for CTQ, PCTQ = 0
  ///  - The Denominator for CTQ, DCTQ = 0
  ///  - The Divider factor PDIV = 16
  ///  - Shift Clock output configuration (SCLKCFG) = 1, Clock polarity =1

  USIC0_CH0->BRG = 0x40100000UL;

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Input Control Register:
  ///  -----------------------------------------------------------------------
  ///  - The data input DX0A is selected  P1.5 
  ///  - The Input of the Shift Unit is directly connected to the input line (INSW = 1)	
  USIC0_CH0->DX0CR = (0x0010UL | U0C0DX0CR);


	///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Interrupt Node Pointer Register:
  ///  -----------------------------------------------------------------------
  ///  - Alternate Receive Interrupt pointer points to Interrupt node U0C0_1IC
	///  - Receive Interrupt pointer points to Interrupt node U2C0_1IC
  ///  - Transmit Shift Interrupt pointer points to Interrupt node U0C0_0IC
  USIC0_CH0->INPR = 0x1100UL;
                                 // H

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Shift Control:
  ///  -----------------------------------------------------------------------
  ///  - Transmit/Receive MSB first is selected
	///  - Passive Data Level = 1
	///  - Word Length (WLE) = 7
  ///  - Frame Length (FLE) = 7

  USIC0_CH0->SCTR = 0x07070103UL;

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Transmit Control/Status Register:
  ///  -----------------------------------------------------------------------
  USIC0_CH0->TCSR = 0x0500UL;
	

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Protocol Control Register:
  ///  -----------------------------------------------------------------------

  USIC0_CH0->PCR =  0x0007UL;      // load U2C1 protocol control register L

  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Protocol Status Register:
  ///  -----------------------------------------------------------------------
  ///  - TBIF is set to simplify polling

  USIC0_CH0->PSR      |=  0x2000;      // load U2C1 protocol status register


  ///  -----------------------------------------------------------------------
  ///  Configuration of the U0C0 Channel Control Register (Mode & Interrupts):
  ///  -----------------------------------------------------------------------
  ///  - SSC (SPI) Protocol is selected 
  ///  - The parity generation is disabled
  ///  - Transmit shift interrupt is enabled
  ///  - Alternate receive interrupt is enabled
  ///  - Receive interrupt is enabled

 USIC0_CH0->CCR       =  0xd001;      // load U2C1 channel control register

  ///  -----------------------------------------------------------------------
  ///  Configuration of U0C0 FIFO:
  ///  -----------------------------------------------------------------------
  ///  -----------------------------------------------------------------------
  ///  Configuration of U0C0 Transmitter Buffer Conrol Register:
  ///  -----------------------------------------------------------------------
  ///  - Transmit FIFO buffer is disabled
  ///  -----------------------------------------------------------------------
  ///  Configuration of U0C0 Receiver Buffer Conrol Register:
  ///  -----------------------------------------------------------------------
  ///  - Receive FIFO buffer is disabled

}

void USIC0_vInit (void) {
  SCU_RESET->PRCLR0 = 0x0800UL;  // Reset des USIC0 zurcksetzen
	U0C0_SSC_vInit();
	USIC0C1_ASC_vInit(C9600, ACHTDB, KEINEP, EINSTOPBIT);
}
