/*===========================================================================*/
/* LIB    : TAS300                                                           */
/* MODUL  : cflash_at28c256.h                                                */
/* AUTHOR : Buchbauer                                                        */
/* DATUM  : 30. 11. 2004                                                     */
// ----------------------------------------------------------------------------
// X40: EEPROM-Emulation 
//	(Daten werden ber SPI-Bus im FRAM remanent gespeichert, und im RAM abgebildet)
/*===========================================================================*/

#include "basic_typedef.h"
#include "FlashA25L032.h"
#include "USIC/U0C0_SPI_Memory.h"

extern unsigned int Image$$EEDATA$$Base; // Start-Address of EEPROM data
extern unsigned int Image$$EEDATA$$Length; // Length of the section (ie. 0x20000)
extern unsigned int Image$$EEDATA$$Limit; // Address of first byte beyond EEPROM data

// 128 KB:
#define EEPROM_START ((ULONG)&Image$$EEDATA$$Base)
#define EEPROM_END   (((ULONG)&Image$$EEDATA$$Base) + 0x1FFFF)
#define EEPROMPAGESIZE   4096
#define EEPROMPAGEANZ      32

// Return : 0 .. success, otherwise error code
UINT32 read_spi_framdata_for_eeprom (ULONG address, UINT length, void huge *destptr) { 
	ULONG _ulong;
	
	_ulong = A25READADDRESS(address);  
	memcpy (spi_sendbuffer, &_ulong, 4);
	write_to_spi (SPI_ADRESSE_FRAM2, spi_sendbuffer, 4, destptr, length);

	return 0;
}

/*===========================================================================*/
/* Name   : reload_eeprom_data ()                                            */
/* Aufgabe: Daten beim Reboot zurcklesen                                    */
/*===========================================================================*/
UINT32 reload_eeprom_data (void) {
	UINT ret = 0;
  ULONG i;
	ULONG address = EEPROM_START;

	for (i=0; i<EEPROMPAGEANZ && ret == 0; i++) {
		ret = read_spi_framdata_for_eeprom ((i*EEPROMPAGESIZE), EEPROMPAGESIZE, (void huge *) address);
		address += EEPROMPAGESIZE;
	}
	return ret;
}
