/*===========================================================================*/
/* LIB    : TAS300                                                           */
/* MODUL  : serieller_flash_driver.C                                         */
/* AUFGABE: Treiberprozeduren fr SPI-Flash                                  */
/* AUTHOR : Buchbauer                                                        */
/* DATUM  : 7. 3. 2006                                                       */
/*===========================================================================*/

#ifndef _SERIELLER_FLASH_DRIVER_H
#define _SERIELLER_FLASH_DRIVER_H

#include <basic_typedef.h>

#define FLASH_MAX_PAGE  1024     // Es werden alle 1024 Pages fr den Flash Treiber verwendet

#define FLASHANZAHL 1
#define FLASHGROESSE 1024        // Anzahl an Pages mit 4096 Byte
#define FLASH_PAGE_SIZE 4096     // Gte einer Page
#define FLASH_MAXWRITE_SIZE 256  // Maxial 256 Byte einer Page knnen maximal beschrieben werden

/*===========================================================================*/
/**Name   : init_serieller_flash_driver ()     
 * Aufgabe: Treiber des serielleen FLASH initialisieren                      *
 *===========================================================================*/
extern void init_serieller_flash_driver ();

/*===========================================================================*/
/**Name   : get_page_buffer ()
 * Aufgabe: Den Buffer fr eine Page anfordern                               *
 *===========================================================================*/
extern void* get_page_buffer ();

/*===========================================================================*/
/**Name   : release_page_buffer ()
 * Aufgabe: Den Buffer wieder freigeben                                      *
 *===========================================================================*/
extern void release_page_buffer ();

/*===========================================================================*/
/**Name   : init_flash_page ()     
 * Aufgabe: Initialisieren eines Blocks im Flash                             *
 *===========================================================================*/
extern void init_flash_page (UINT page);

/*===========================================================================*/
/**Name   : write_flashpage (UINT page, void *daten, UINT length)
 * Aufgabe: Schreiben einer Flashpage                                        *
 *===========================================================================*/
extern void write_flashpage ( UINT page, void *daten, UINT length );

/*===========================================================================*/
/**Name   : read_flashpage (UCHR line, void *daten, UINT length)
 * Aufgabe: Lesen einer Flashpage                                            *
 *===========================================================================*/
extern void read_flashpage ( UINT page, void *daten, UINT length );

/*===========================================================================*/
/**Name   : UnprotectSpiFlashCS2 ()
 * Aufgabe: Flash ist nach Power Up schreibgeschtzt -> aufheben             *
 *===========================================================================*/
extern void UnprotectSpiFlashCS2 (void); 


#endif
/*===========================================================================*/
/*                        E N D  O F  M O D U L E                            */
/*===========================================================================*/
