/******************************************************************************
 * @file     MyMultiplexer.c
 * @brief    Define Usage of Port Pins
 *           for the Infineon XMC4500 Device Series
 * @version  V0.0.1
 * @date     10. Dec 2014
 *
 ******************************************************************************/

/********************** Version History ***************************************
 * V3.0.4, Dec 2014, Added options to configure clock settings
 ******************************************************************************/

/*******************************************************************************
 * HEADER FILES
 *******************************************************************************/

#include "basic_typedef.h"

/*******************************************************************************
 * MACROS
 *******************************************************************************/

/* Define WEAK attribute */
#if !defined(__WEAK)
#if defined ( __CC_ARM )
#define __WEAK __attribute__ ((weak))
#elif defined ( __ICCARM__ )
#define __WEAK __weak
#elif defined ( __GNUC__ )
#define __WEAK __attribute__ ((weak))
#elif defined ( __TASKING__ )
#define __WEAK __attribute__ ((weak))
#endif
#endif



/*******************************************************************************
 * GLOBAL VARIABLES
 *******************************************************************************/

/*******************************************************************************
 * LOCAL FUNCTIONS
 *******************************************************************************/
/*
//-------- <<< Use Configuration Wizard in Context Menu >>> ------------------
*/

/*
// <h> Port0
*/

/*
// ---------------- Port 0.0 --------------------------------------------------
// <h> Port0.0
//    <o> Port 0.0 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / CAN.N0_TXD (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT21 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.COL2 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP00 (18U)

/*
//    <o> Port 0.0 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP00 (0U)

/*
//    <o> Port 0.0 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP00 (0U)
// 		</h>

/*
// ---------------- Port 0.1 --------------------------------------------------
// <h> Port0.1
//    <o> Port 0.1 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / USB.Driverbus (Alternate Output Function 1)
//       <0x12=> Push-Pull / U1C1.DOUT0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT11 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.COL3 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP01 (18U)

/*
//    <o> Port 0.1 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP01 (0U)

/*
//    <o> Port 0.1 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP01 (0U)
// 		</h>


/*
// ---------------- Port 0.2 --------------------------------------------------
// <h> Port0.2
//    <o> Port 0.2 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C1.SELO1 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT01 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP02 (0U)

/*
//    <o> Port 0.2 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP02 (0U)

/*
//    <o> Port 0.2 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U1C0.HWIN3 (HWI0)/U1C0.DOUT3 (HWO0)
//       <0x02=> EBU.D0 (HWI1)/EBU.AD0 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP02 (2U)
// 		</h>

/*
// ---------------- Port 0.3 --------------------------------------------------
// <h> Port0.3
//    <o> Port 0.3 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU80.OUT20 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP03 (0U)

/*
//    <o> Port 0.3 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP03 (0U)

/*
//    <o> Port 0.3 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U1C0.HWIN2 (HWI0)/U1C0.DOUT2 (HWO0)
//       <0x02=> EBU.D1 (HWI1)/EBU.AD1 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP03 (2U)
// 		</h>

/*
// ---------------- Port 0.4 --------------------------------------------------
// <h> Port0.4
//    <o> Port 0.4 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TX_EN (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU80.OUT10 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP04 (0U)

/*
//    <o> Port 0.4 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP04 (0U)

/*
//    <o> Port 0.4 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U1C0.HWIN1 (HWI0)/U1C0.DOUT1 (HWO0)
//       <0x02=> EBU.D2 (HWI1)/EBU.AD2 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP04 (2U)
// 		</h>

/*
// ---------------- Port 0.5 --------------------------------------------------
// <h> Port0.5
//    <o> Port 0.5 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TXD0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U1D0.DOUT0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT00 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP05 (0U)

/*
//    <o> Port 0.5 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP05 (0U)

/*
//    <o> Port 0.5 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U1C0.HWIN0 (HWI0)/ U1C0.DOUT0 (HWO0)
//       <0x02=> EBU.D3 (HWI1)/ EBU.AD3 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP05 (2U)
// 		</h>

/*
// ---------------- Port 0.6 --------------------------------------------------
// <h> Port0.6
//    <o> Port 0.6 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / EHT0.TXD1 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U1C0.SELO0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT30 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP06 (16U)

/*
//    <o> Port 0.6 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP06 (0U)

/*
//    <o> Port 0.6 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/ #EBU.ADV (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP06 (2U)
// 		</h>

/*
// ---------------- Port 0.7 --------------------------------------------------
// <h> Port0.7
//    <o> Port 0.7 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / WWDT.SERVICE_OUT (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C0.SELO0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP07 (0U)

/*
//    <o> Port 0.7 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP07 (0U)

/*
//    <o> Port 0.7 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> DB.TDI (HWI0)/HWO0
//       <0x02=> EBU.D6 (HWI1)/ EBU.AD6 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP07 (2U)
// 		</h>

/*
// ---------------- Port 0.8 --------------------------------------------------
// <h> Port0.8
//    <o> Port 0.8 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / SCU.EXTCLK (Alternate Output Function 1)
//       <0x12=> Push-Pull / D0C0.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP08 (0U)

/*
//    <o> Port 0.8 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP08 (0U)

/*
//    <o> Port 0.8 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> #DB.TRST (HWI0)/HWO0
//       <0x02=> EBU.D7 (HWI1)/ EBU.AD7 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP08 (2U)
// 		</h>

/*
// ---------------- Port 0.9 --------------------------------------------------
// <h> Port0.9
//    <o> Port 0.9 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C1.SELO0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT12 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.COL0 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP09 (0U)

/*
//    <o> Port 0.9 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP09 (0U)

/*
//    <o> Port 0.9 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> ETH0.MDIA (HWI0)/ ETH0.MDO (HWO0)
//       <0x02=> HWI1/ #EBU.CS1 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP09 (2U)
// 		</h>

/*
// ---------------- Port 0.10 --------------------------------------------------
// <h> Port0.10
//    <o> Port 0.10 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.MDC (Alternate Output Function 1)
//       <0x12=> Push-Pull / U1C1.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT02 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.COL1 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP010 (2U)

/*
//    <o> Port 0.10 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP010 (0U)

/*
//    <o> Port 0.10 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP010 (0U)
// 		</h>

/*
// ---------------- Port 0.11 --------------------------------------------------
// <h> Port0.11
//    <o> Port 0.11 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C0.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT31 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP011 (0U)

/*
//    <o> Port 0.11 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP011 (0U)

/*
//    <o> Port 0.11 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ #SDMMC.RST (HWO0)
//       <0x02=> HWI1/ #EBU.BREQ (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP011 (0U)
// 		</h>

/*
// ---------------- Port 0.12 --------------------------------------------------
// <h> Port0.12
//    <o> Port 0.12 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C1.SELO0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU40.OUT3 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP012 (0U)

/*
//    <o> Port 0.12 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP012 (0U)

/*
//    <o> Port 0.12 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> #EBU.HLDA (HWI1)/ #EBU.HLDA (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP012 (0U)
// 		</h>

/*
// ---------------- Port 0.13 --------------------------------------------------
// <h> Port0.13
//    <o> Port 0.13 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C1.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU40.OUT2 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP013 (0U)

/*
//    <o> Port 0.13 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP013 (0U)

/*
//    <o> Port 0.13 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP013 (0U)
// 		</h>

/*
// ---------------- Port 0.14 --------------------------------------------------
// <h> Port0.14
//    <o> Port 0.14 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C0.SELO1 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU40.OUT1 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP014 (16U)

/*
//    <o> Port 0.14 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP014 (0U)

/*
//    <o> Port 0.14 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U1C1.DOUT3 (HWI0)/ U1C1.HWIN3 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP014 (0U)
// 		</h>

/*
// ---------------- Port 0.15 --------------------------------------------------
// <h> Port0.15
//    <o> Port 0.15 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C0.SELO2 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU40.OUT0 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP015 (16U)

/*
//    <o> Port 0.15 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP015 (0U)

/*
//    <o> Port 0.15 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U1C1.DOUT2 (HWI0)/ U1C1.HWIN2 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP015 (0U)
// 		</h>

//    </h>

/*
// ---------------- Port 1 --------------------------------------------------
// <h> Port1
*/

/*
// ---------------- Port 1.0 --------------------------------------------------
// <h> Port1.0
//    <o> Port 1.0 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / DSD.CGPWMN (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C0.SELO0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU40.OUT3 (Alternate Output Function 3)
//       <0x14=> Push-Pull / ERU1.PDOUT3 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP10 (16U)

/*
//    <o> Port 1.0 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP10 (0U)

/*
//    <o> Port 1.0 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP10 (0U)
//    </h>
/*
// ---------------- Port 1.1 --------------------------------------------------
// <h> Port1.1
//    <o> Port 1.1 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / DSD.CGPWMP (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C0.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU40.OUT2 (Alternate Output Function 3)
//       <0x14=> Push-Pull / ERU1.PDOUT2 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP11 (18U)

/*
//    <o> Port 1.1 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP11 (0U)

/*
//    <o> Port 1.1 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.SDWC (HWI0)/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP11 (0U)
//    </h>
/*
// ---------------- Port 1.2 --------------------------------------------------
// <h> Port1.2
//    <o> Port 1.2 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU40.OUT1 (Alternate Output Function 3)
//       <0x14=> Push-Pull / ERU1.PDOUT1 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP12 (0U)

/*
//    <o> Port 1.2 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP12 (0U)

/*
//    <o> Port 1.2 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U0C0.HWIN3 (HWI0)/ U0C0.DOUT3 (HWO0)
//       <0x02=> EBU.D14 (HWI1)/ EBU.AD14 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP12 (2U)
//    </h>
/*
// ---------------- Port 1.3 --------------------------------------------------
// <h> Port1.3
//    <o> Port 1.3 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C0.MCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU40.OUT0 (Alternate Output Function 3)
//       <0x14=> Push-Pull / ERU1.PDOUT0 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP13 (0U)

/*
//    <o> Port 1.3 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP13 (0U)

/*
//    <o> Port 1.3 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U0C0.HWIN2 (HWI0)/ U0C0.DOUT2 (HWO0)
//       <0x02=> EBU.D15 (HWI1)/ EBU.AD15 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP13 (2U)
//    </h>

/*
// ---------------- Port 1.4 --------------------------------------------------
// <h> Port1.4
//    <o> Port 1.4 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / WWDT.SERVICE_OUT (Alternate Output Function 1)
//       <0x12=> Push-Pull / CAN.N0_TXD (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT33 (Alternate Output Function 3)
//       <0x14=> Push-Pull / CCU81.OUT20 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP14 (0U)

/*
//    <o> Port 1.4 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP14 (0U)

/*
//    <o> Port 1.4 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U0C0.HWIN1 (HWI0)/ U0C0.DOUT1 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP14 (0U)
//    </h>

/*
// ---------------- Port 1.5 --------------------------------------------------
// <h> Port1.5
//    <o> Port 1.5 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / CAN.N1_TXD (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C0.DOUT0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT23 (Alternate Output Function 3)
//       <0x14=> Push-Pull / U0C0.DOUT0 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP15 (0U)

/*
//    <o> Port 1.5 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP15 (0U)

/*
//    <o> Port 1.5 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U0C0.HWIN0 (HWI0)/ U0C0.DOUT0 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP15 (0U)
//    </h>

/*
// ---------------- Port 1.6 --------------------------------------------------
// <h> Port1.6
//    <o> Port 1.6 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C0.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP16 (0U)

/*
//    <o> Port 1.6 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP16 (0U)

/*
//    <o> Port 1.6 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.DATA1_IN (HWI0)/ SDMMC.DATA1_OUT (HWO0)
//       <0x02=> EBU.D10 (HWI1)/ EBU.AD10 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP16 (2U)
//    </h>

/*
// ---------------- Port 1.7 --------------------------------------------------
// <h> Port1.7
//    <o> Port 1.7 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C0.DOUT0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / DSD.MCLK2 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP17 (0U)

/*
//    <o> Port 1.7 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP17 (0U)

/*
//    <o> Port 1.7 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.DATA2_IN (HWI0)/ SDMMC.DATA2_OUT (HWO0)
//       <0x02=> EBU.D11 (HWI1)/ EBU.AD11 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP17 (2U)
//    </h>

/*
// ---------------- Port 1.8 --------------------------------------------------
// <h> Port1.8
//    <o> Port 1.8 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C0.SELO1 (Alternate Output Function 2)
//       <0x13=> Push-Pull / DSD.MCLK1 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP18 (0U)

/*
//    <o> Port 1.8 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP18 (0U)

/*
//    <o> Port 1.8 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.DATA4_IN (HWI0)/ SDMMC.DATA4_OUT (HWO0)
//       <0x02=> EBU.D12 (HWI1)/ EBU.AD12 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP18 (2U)
//    </h>

/*
// ---------------- Port 1.9 --------------------------------------------------
// <h> Port1.9
//    <o> Port 1.9 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / CAN.N2_TXD (Alternate Output Function 2)
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP19 (0U)

/*
//    <o> Port 1.9 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP19 (0U)

/*
//    <o> Port 1.9 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.DATA5_IN (HWI0)/ SDMMC.DATA5_OUT (HWO0)
//       <0x02=> EBU.D13 (HWI1)/ EBU.AD13 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP19 (2U)
//    </h>

/*
// ---------------- Port 1.10 --------------------------------------------------
// <h> Port1.10
//    <o> Port 1.10 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.MDC (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C0.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU81.OUT21 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP110 (17U)

/*
//    <o> Port 1.10 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP110 (0U)

/*
//    <o> Port 1.10 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> #SDMMC.SDCD (HWI0)/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP110 (0U)
//    </h>

/*
// ---------------- Port 1.11 --------------------------------------------------
// <h> Port1.11
//    <o> Port 1.11 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C0.SELO0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU81.OUT11 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP111 (16U)

/*
//    <o> Port 1.11 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP111 (0U)

/*
//    <o> Port 1.11 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> ETH0.MDIC (HWI0)/ ETH0.MDO (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP111 (1U)
//    </h>

/*
// ---------------- Port 1.12 --------------------------------------------------
// <h> Port1.12
//    <o> Port 1.12 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TX_EN (Alternate Output Function 1)
//       <0x12=> Push-Pull / CAN.N1_TXD (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU81.OUT01 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP112 (17U)

/*
//    <o> Port 1.12 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP112 (0U)

/*
//    <o> Port 1.12 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.DATA6_IN (HWI0)/ SDMMC.DATA6_OUT (HWO0)
//       <0x02=> EBU.D16 (HWI1)/ EBU.AD16 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP112 (0U)
//    </h>

/*
// ---------------- Port 1.13 --------------------------------------------------
// <h> Port1.13
//    <o> Port 1.13 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / EHT0.TXD0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.SELO3 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU81.OUT20 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP113 (0U)

/*
//    <o> Port 1.13 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP113 (0U)

/*
//    <o> Port 1.13 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.DATA7_IN (HWI0)/ SDMMC.DATA7_OUT (HWO0)
//       <0x02=> EBU.D17 (HWI1)/ EBU.AD17 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP113 (0U)
//    </h>

/*
// ---------------- Port 1.14 --------------------------------------------------
// <h> Port1.14
//    <o> Port 1.14 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TXD1 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.SELO2 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU81.OUT10 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP114 (0U)

/*
//    <o> Port 1.14 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP114 (0U)

/*
//    <o> Port 1.14 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> EBU.D18 (HWI1)/ EBU.AD18 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP114 (0U)
//    </h>

/*
// ---------------- Port 1.15 --------------------------------------------------
// <h> Port1.15
//    <o> Port 1.15 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / SCU.EXTCLK (Alternate Output Function 1)
//       <0x12=> Push-Pull / DSD.MCLK2 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU81.OUT00 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP115 (17U)

/*
//    <o> Port 1.15 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP115 (0U)

/*
//    <o> Port 1.15 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> EBU.D19 (HWI1)/ EBU.AD19 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP115 (0U)
//    </h>

//    </h>

/*
// ---------------- Port 2 --------------------------------------------------
// <h> Port2
*/

/*
// ---------------- Port 2.0 --------------------------------------------------
// <h> Port2.0
//    <o> Port 2.0 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / CCU81.OUT21 (Alternate Output Function 2)
//       <0x13=> Push-Pull / DSD.CDPWMN (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.COL1 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP20 (0U)

/*
//    <o> Port 2.0 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP20 (0U)

/*
//    <o> Port 2.0 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> ETH0.MDIB (HWI0)/ ETH0.MDO (HWO0)
//       <0x02=> EBU.D20 (HWI1)/ EBU.AD20 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP20 (0U)
//    </h>
/*
// ---------------- Port 2.1 --------------------------------------------------
// <h> Port2.1
//    <o> Port 2.1 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / CCU81.OUT11 (Alternate Output Function 2)
//       <0x13=> Push-Pull / DSD.CGPWMP (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.COL0 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP21 (0U)

/*
//    <o> Port 2.1 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP21 (0U)

/*
//    <o> Port 2.1 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DB.TDO/TRACESWO (HWO0)
//       <0x02=> EBU.D21 (HWI1)/ EBU.AD21 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP21 (1U)
//    </h>
/*
// ---------------- Port 2.2 --------------------------------------------------
// <h> Port2.2
//    <o> Port 2.2 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / VADC.EMUX00 (Alternate Output Function 1)
//       <0x12=> Push-Pull / CCU81.OUT01 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU41.OUT3 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE0 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP22 (0U)

/*
//    <o> Port 2.2 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP22 (0U)

/*
//    <o> Port 2.2 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> LEDTS0.TSIN0A (HWI0)/ LEDTS0.EXTENDED0 (HWO0)
//       <0x02=> EBU.D22 (HWI1)/ EBU.AD22 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP22 (0U)
//    </h>
/*
// ---------------- Port 2.3 --------------------------------------------------
// <h> Port2.3
//    <o> Port 2.3 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / VADC.EMUX00 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.SELO0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU41.OUT2 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE1 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP23 (0U)

/*
//    <o> Port 2.3 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP23 (0U)

/*
//    <o> Port 2.3 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> LEDTS0.TSIN1A (HWI0)/ LEDTS0.EXTANDED1 (HWO0)
//       <0x02=> EBU.D23 (HWI1)/ EBU.AD23 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP23 (0U)
//    </h>

/*
// ---------------- Port 2.4 --------------------------------------------------
// <h> Port2.4
//    <o> Port 2.4 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / VADC.EMUX02 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU41.OUT1 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE2 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP24 (0U)

/*
//    <o> Port 2.4 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP24 (0U)

/*
//    <o> Port 2.4 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> LEDTS0.TSIN2A (HWI0)/ LEDTS0.EXTENDED2 (HWO0)
//       <0x02=> EBU.D24 (HWI1)/ EBU.AD24 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP24 (0U)
//    </h>

/*
// ---------------- Port 2.5 --------------------------------------------------
// <h> Port2.5
//    <o> Port 2.5 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TX_EN (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.DOUT0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU41.OUT0 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE3 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP25 (0U)

/*
//    <o> Port 2.5 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP25 (0U)

/*
//    <o> Port 2.5 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> LEDTS0.TSIN3A (HWI0)/ LEDTS0.EXTENDED3 (HWO0)
//       <0x02=> EBU.D25 (HWI1)/ EBU.AD25 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP25 (0U)
//    </h>

/*
// ---------------- Port 2.6 --------------------------------------------------
// <h> Port2.6
//    <o> Port 2.6 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C0.SELO4 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU80.OUT13 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.COL3 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP26 (0U)

/*
//    <o> Port 2.6 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP26 (0U)

/*
//    <o> Port 2.6 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U2C0.HWIN3 (HWI0)/ U2C0.DOUT (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP26 (0U)
//    </h>

/*
// ---------------- Port 2.7 --------------------------------------------------
// <h> Port2.7
//    <o> Port 2.7 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.MDC (Alternate Output Function 1)
//       <0x12=> Push-Pull / CAN.N1_TXD (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT03 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.COL2 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP27 (18U)

/*
//    <o> Port 2.7 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP27 (0U)

/*
//    <o> Port 2.7 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP27 (0U)
//    </h>

/*
// ---------------- Port 2.8 --------------------------------------------------
// <h> Port2.8
//    <o> Port 2.8 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TXD0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU80.OUT32 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE4 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP28 (16U)

/*
//    <o> Port 2.8 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP28 (0U)

/*
//    <o> Port 2.8 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> LEDTS0.TSIN4A (HWI0)/ LEDTS0.EXTENDED4 (HWO0)
//       <0x02=> EBU.D26 (HWI1)/ EBU.AD26 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP28 (0U)
//    </h>

/*
// ---------------- Port 2.9 --------------------------------------------------
// <h> Port2.9
//    <o> Port 2.9 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TXD1 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU80.OUT22 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE5 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP29 (16U)

/*
//    <o> Port 2.9 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP29 (0U)

/*
//    <o> Port 2.9 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> LEDTS0.TSIN5A (HWI0)/ LEDTS0.EXTENDED5 (HWO0)
//       <0x02=> EBU.D27 (HWI1)/ EBU.AD27 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP29 (0U)
//    </h>

/*
// ---------------- Port 2.10 --------------------------------------------------
// <h> Port2.10
//    <o> Port 2.10 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / VADC.EMUX10 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP210 (0U)

/*
//    <o> Port 2.10 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP210 (2U)

/*
//    <o> Port 2.10 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DB.ETM_TRACEDATA3 (HWO0)
//       <0x02=> EBU.D28 (HWI1)/ EBU.AD28 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP210 (0U)
//    </h>

/*
// ---------------- Port 2.11 --------------------------------------------------
// <h> Port2.11
//    <o> Port 2.11 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TXER (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU80.OUT22 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP211 (0U)

/*
//    <o> Port 2.11 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP211 (0U)

/*
//    <o> Port 2.11 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/DB.ETM_TRACEDATA2 (HWO0)
//       <0x02=> EBU.D29 (HWI1)/EBU.AD29 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP211 (0U)
//    </h>

/*
// ---------------- Port 2.12 --------------------------------------------------
// <h> Port2.12
//    <o> Port 2.12 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TXD2 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU81.OUT33 (Alternate Output Function 3)
//       <0x14=> Push-Pull / ETH0.TXD0 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP212 (20U)

/*
//    <o> Port 2.12 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP212 (0U)

/*
//    <o> Port 2.12 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DB.ETM_TRACEDATA1 (HWO0)
//       <0x02=> EBU.D30 (HWI1)/ EBU.AD30 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP212 (0U)
//    </h>

/*
// ---------------- Port 2.13 --------------------------------------------------
// <h> Port2.13
//    <o> Port 2.13 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TXD3 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / EHT0.TXD1 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP213 (20U)

/*
//    <o> Port 2.13 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP213 (0U)

/*
//    <o> Port 2.13 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DB.ETM_TRACEDATA0 (HWO0)
//       <0x02=> EBU.D31 (HWI1)/ EBU.AD31 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP213 (0U)
//    </h>

/*
// ---------------- Port 2.14 --------------------------------------------------
// <h> Port2.14
//    <o> Port 2.14 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / VADC.EMUX11 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U1C0.DOUT0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT21 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP214 (0U)

/*
//    <o> Port 2.14 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP214 (0U)

/*
//    <o> Port 2.14 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DB.TRACECLK (HWO0)
//       <0x02=> HWI1/ #EBU.BC0 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP214 (2U)
//    </h>

/*
// ---------------- Port 2.15 --------------------------------------------------
// <h> Port2.15
//    <o> Port 2.15 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / VADC.EMUX12 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU80.OUT11 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE6 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP215 (0U)

/*
//    <o> Port 2.15 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP215 (0U)

/*
//    <o> Port 2.15 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> LEDTS0.TSIN6A (HWI0)/ LEDTS0.EXTENDED6 (HWO0)
//       <0x02=> HWI1/ #EBU.BC1 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP215 (2U)
//    </h>

//    </h>

/*
// ---------------- Port 3 --------------------------------------------------
// <h> Port3
*/

/*
// ---------------- Port 3.0 --------------------------------------------------
// <h> Port3.0
//    <o> Port 3.0 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C1.SELO0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU42.OUT0 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP30 (0U)

/*
//    <o> Port 3.0 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP30 (0U)

/*
//    <o> Port 3.0 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/ #EBU.RD (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP30 (2)
//    </h>
/*
// ---------------- Port 3.1 --------------------------------------------------
// <h> Port3.1
//    <o> Port 3.1 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C1.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP31 (0U)

/*
//    <o> Port 3.1 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP31 (0U)

/*
//    <o> Port 3.1 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/ #EBU.RD_WR (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP31 (2U)
//    </h>
/*
// ---------------- Port 3.2 --------------------------------------------------
// <h> Port3.2
//    <o> Port 3.2 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / USB.DRIVEBUS (Alternate Output Function 1)
//       <0x12=> Push-Pull / CAN.N0_TXD (Alternate Output Function 2)
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / LEDTS0.COLA (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP32 (0U)

/*
//    <o> Port 3.2 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP32 (0U)

/*
//    <o> Port 3.2 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/ #EBU.CS0 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP32 (2U)
//    </h>
/*
// ---------------- Port 3.3 --------------------------------------------------
// <h> Port3.3
//    <o> Port 3.3 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C1.SELO1 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU42.OUT3 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP33 (0U)

/*
//    <o> Port 3.3 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP33 (0U)

/*
//    <o> Port 3.3 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ SDMMC.LED (HWO0)
//       <0x02=> #EBU.WAIT (HWI1)/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP33 (0U)
//    </h>

/*
// ---------------- Port 3.4 --------------------------------------------------
// <h> Port3.4
//    <o> Port 3.4 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C1.MCLKOUT (Alternate Output Function 1)
//       <0x12=> Push-Pull / U1C1.SELO2 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU42.OUT2 (Alternate Output Function 3)
//       <0x14=> Push-Pull / DSD.MCLK3 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP34 (0U)

/*
//    <o> Port 3.4 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP34 (0U)

/*
//    <o> Port 3.4 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ SDMMC.BUS_POWER (HWO0)
//       <0x02=> #EBU.HOLD (HWI1)/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP34 (0U)
//    </h>

/*
// ---------------- Port 3.5 --------------------------------------------------
// <h> Port3.5
//    <o> Port 3.5 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C1.DOUT0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U1C1.SELO2 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU42.OUT1 (Alternate Output Function 3)
//       <0x14=> Push-Pull / U0C1.DOUT0 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP35 (0U)

/*
//    <o> Port 3.5 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP35 (0U)

/*
//    <o> Port 3.5 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.CMD_IN (HWI0)/ SDMMC.CMD_OUT (HWO0)
//       <0x02=> EBU.D4 (HWI1)/ EBU.AD4 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP35 (2U)
//    </h>

/*
// ---------------- Port 3.6 --------------------------------------------------
// <h> Port3.6
//    <o> Port 3.6 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C1.SCLKOUT (Alternate Output Function 1)
//       <0x12=> Push-Pull / U1C1.SELO4 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU42.OUT0 (Alternate Output Function 3)
//       <0x14=> Push-Pull / U0C1.SCLKOUT (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP36 (0U)

/*
//    <o> Port 3.6 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP36 (0U)

/*
//    <o> Port 3.6 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.CLK_IN (HWI0)/DSMMC.CLK_IN (HWO0)
//       <0x02=> EBU.D5 (HWI1)/ EBU.AD5 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP36 (2U)
//    </h>

/*
// ---------------- Port 3.7 --------------------------------------------------
// <h> Port3.7
//    <o> Port 3.7 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / CAN.N2_TXD (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU41.OUT3 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE0 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP37 (0U)

/*
//    <o> Port 3.7 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP37 (0U)

/*
//    <o> Port 3.7 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP37 (0U)
//    </h>

/*
// ---------------- Port 3.8 --------------------------------------------------
// <h> Port3.8
//    <o> Port 3.8 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C0.DOUT0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.SELO3 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU41.OUT2 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE1 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP38 (0U)

/*
//    <o> Port 3.8 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP38 (0U)

/*
//    <o> Port 3.8 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP38 (0U)
//    </h>

/*
// ---------------- Port 3.9 --------------------------------------------------
// <h> Port3.9
//    <o> Port 3.9 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C0.SCLKOUT (Alternate Output Function 1)
//       <0x12=> Push-Pull / CAN.N1_TXD (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU41.OUT1 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE2 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP39 (17U)

/*
//    <o> Port 3.9 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP39 (0U)

/*
//    <o> Port 3.9 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP39 (0U)
//    </h>

/*
// ---------------- Port 3.10 --------------------------------------------------
// <h> Port3.10
//    <o> Port 3.10 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C0.SELO0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / CAN.N0_TXD (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU41.OUT0 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE3 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP310 (16U)

/*
//    <o> Port 3.10 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP310 (0U)

/*
//    <o> Port 3.10 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U0C1.HWIN3 (HWI0)/ U0C1.DOUT3 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP310 (0U)
//    </h>

/*
// ---------------- Port 3.11 --------------------------------------------------
// <h> Port3.11
//    <o> Port 3.11 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C1.DOUT0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.SELO2 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU42.OUT3 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE4 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP311 (17U)

/*
//    <o> Port 3.11 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP311 (0U)

/*
//    <o> Port 3.11 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U0C1.HWIN2 (HWI0)/ U0C1.DOUT2 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP311 (0U)
//    </h>

/*
// ---------------- Port 3.12 --------------------------------------------------
// <h> Port3.12
//    <o> Port 3.12 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C1.SELO (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU42.OUT2 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE5 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP312 (0U)

/*
//    <o> Port 3.12 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP312 (0U)

/*
//    <o> Port 3.12 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U0C1.HWIN1 (HWI0)/ U0C1.DOUT1 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP312 (0U)
//    </h>

/*
// ---------------- Port 3.13 --------------------------------------------------
// <h> Port3.13
//    <o> Port 2.13 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C1.SCLKOUT (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.DOUT0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU42.OUT1 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE6 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP313 (18U)

/*
//    <o> Port 3.13 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP313 (0U)

/*
//    <o> Port 3.13 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U0C1.HWIN0 (HWI0)/ U0C1.DOUT0 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP313 (0U)
//    </h>

/*
// ---------------- Port 3.14 --------------------------------------------------
// <h> Port3.14
//    <o> Port 3.14 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C1.SELO3 (Alternate Output Function 2)
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP314 (0U)

/*
//    <o> Port 3.14 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP314 (0U)

/*
//    <o> Port 3.14 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U1C1.HWIN1 (HWI0)/ U1C1.DOUT1 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP314 (0U)
//    </h>

/*
// ---------------- Port 3.15 --------------------------------------------------
// <h> Port3.15
//    <o> Port 3.15 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C1.DOUT0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP315 (16U)

/*
//    <o> Port 3.15 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP315 (0U)

/*
//    <o> Port 3.15 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U1C1.HWIN0 (HWI0)/ U1C1.DOUT0 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP315 (0U)
//    </h>

//    </h>
/*
// ---------------- Port 4 --------------------------------------------------
// <h> Port4
*/

/*
// ---------------- Port 4.0 --------------------------------------------------
// <h> Port4.0
//    <o> Port 4.0 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / DSD.MCLK1 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP40 (0U)

/*
//    <o> Port 4.0 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP40 (0U)

/*
//    <o> Port 4.0 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.DATA0_IN (HWI0)/ SDMMC.DATA0_OUT (HWO0)
//       <0x02=> EBU.D8 (HWI1)/ EBU.AD8 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP40 (2U)
//    </h>
/*
// ---------------- Port 4.1 --------------------------------------------------
// <h> Port4.1
//    <o> Port 4.1 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C1.SELO0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / DSD.MCLK0 (Alternate Output Function 3)
//       <0x14=> Push-Pull / U0C1.SELO0 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP41 (0U)

/*
//    <o> Port 4.1 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP41 (0U)

/*
//    <o> Port 4.1 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> SDMMC.DATA3_IN (HWI0)/ SDMMC.DATA3_OUT (HWO0)
//       <0x02=> EBU.D9 (HWI1)/ EBU.AD9 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP41 (2U)
//    </h>
/*
// ---------------- Port 4.2 --------------------------------------------------
// <h> Port4.2
//    <o> Port 4.2 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C1.SELO1 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U1C1.DOUT0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / U2C1.SCLKOUT (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP42 (16U)

/*
//    <o> Port 4.2 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP42 (0U)

/*
//    <o> Port 4.2 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP42 (0U)
//    </h>
/*
// ---------------- Port 4.3 --------------------------------------------------
// <h> Port4.3
//    <o> Port 4.3 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C1.SELO2 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C0.SELO5 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU43.OUT3 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP43 (16U)

/*
//    <o> Port 4.3 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP43 (0U)

/*
//    <o> Port 4.3 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP43 (0U)
//    </h>

/*
// ---------------- Port 4.4 --------------------------------------------------
// <h> Port4.4
//    <o> Port 4.4 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C0.SELO4 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU43.OUT2 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP44 (16U)

/*
//    <o> Port 4.4 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP44 (0U)

/*
//    <o> Port 4.4 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U2C1.HWIN3 (HWI0)/ U2C1.DOUT3 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP44 (0U)
//    </h>

/*
// ---------------- Port 4.5 --------------------------------------------------
// <h> Port4.5
//    <o> Port 4.5 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C0.SELO3 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU43.OUT1 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP45 (16U)

/*
//    <o> Port 4.5 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP45 (0U)

/*
//    <o> Port 4.5 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U2C1.HWIN2 (HWI0)/ U2C1.DOUT2 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP45 (0U)
//    </h>

/*
// ---------------- Port 4.6 --------------------------------------------------
// <h> Port4.6
//    <o> Port 4.6 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C0.SELO2 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU43.OUT0 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP46 (16U)

/*
//    <o> Port 4.6 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP46 (0U)

/*
//    <o> Port 4.6 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U2C1.HWIN1 (HWI0)/ U2C1.DOUT1 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP46 (0U)
//    </h>

/*
// ---------------- Port 4.7 --------------------------------------------------
// <h> Port4.7
//    <o> Port 4.7 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / CAN.N2TXD (Alternate Output Function 2)
//       <0x13=> Push-Pull / Alternate Output Function 3
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP47 (18U)

/*
//    <o> Port 4.7 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP47 (0U)

/*
//    <o> Port 4.7 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U2C1.HWIN0 (HWI0)/ U2C1.DOUT0 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP47 (0U)
//    </h>
//    </h>

/*
// ---------------- Port 5 --------------------------------------------------
// <h> Port5
*/

/*
// ---------------- Port 5.0 --------------------------------------------------
// <h> Port5.0
//    <o> Port 5.0 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C0.DOUT0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / DSD.CGPWMN (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU81.OUT33 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP50 (17U)

/*
//    <o> Port 5.0 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP50 (0U)

/*
//    <o> Port 5.0 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U2C0.HWIN0 (HWI0)/ U2C0.DOUT0 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP50 (0U)
//    </h>

/*
// ---------------- Port 5.1 --------------------------------------------------
// <h> Port5.1
//    <o> Port 5.1 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U0C0.DOUT0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / DSD.CGPWMP (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU81.OUT32 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP51 (17U)

/*
//    <o> Port 5.1 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP51 (0U)

/*
//    <o> Port 5.1 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U2C0.HWIN1 (HWI0)/ U2C0.DOUT1 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP51 (0U)
//    </h>

/*
// ---------------- Port 5.2 --------------------------------------------------
// <h> Port5.2
//    <o> Port 5.2 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C0.SCLKOUT (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU81.OUT23 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP52 (16U)

/*
//    <o> Port 5.2 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP52 (0U)

/*
//    <o> Port 5.2 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP52 (0U)
//    </h>
/*
// ---------------- Port 5.3 --------------------------------------------------
// <h> Port5.3
//    <o> Port 5.3 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C0.SELO0 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU81.OUT22 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP53 (0U)

/*
//    <o> Port 5.3 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP53 (0U)

/*
//    <o> Port 5.3 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ EBU.CKE (HWO0)
//       <0x02=> HWI1/ EBU.A20 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP53 (2U)
//    </h>

/*
// ---------------- Port 5.4 --------------------------------------------------
// <h> Port5.4
//    <o> Port 5.4 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C0.SELO1 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU81.OUT13 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP54 (0U)

/*
//    <o> Port 5.4 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP54 (0U)

/*
//    <o> Port 5.4 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ #EBU.RAS (HWO0)
//       <0x02=> HWI1/ EBU.A21 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP54 (2U)
//    </h>

/*
// ---------------- Port 5.5 --------------------------------------------------
// <h> Port5.5
//    <o> Port 5.5 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C0.SELO2 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU81.OUT12 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP55 (0U)

/*
//    <o> Port 5.5 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP55 (0U)

/*
//    <o> Port 5.5 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ #EBU.CAS (HWO0)
//       <0x02=> HWI1/ EBU.A22 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP55 (2U)
//    </h>

/*
// ---------------- Port 5.6 --------------------------------------------------
// <h> Port5.6
//    <o> Port 5.6 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / U2C0.SELO3 (Alternate Output Function 1)
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU81.OUT03 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP56 (0U)

/*
//    <o> Port 5.6 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP56 (0U)

/*
//    <o> Port 5.6 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ EBU.BFCLKO (HWO0)
//       <0x02=> HWI1/ EBU.A23 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP56 (2U)
//    </h>

/*
// ---------------- Port 5.7 --------------------------------------------------
// <h> Port5.7
//    <o> Port 5.7 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU81.OUT02 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.COLA (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP57 (16U)

/*
//    <o> Port 5.7 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP57 (0U)

/*
//    <o> Port 5.7 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> U2C0.HWIN2 (HWI0)/ U2C0.DOUT2 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP57 (0U)
//    </h>

/*
// ---------------- Port 5.8 --------------------------------------------------
// <h> Port5.8
//    <o> Port 5.8 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C0.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT01 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP58 (0U)

/*
//    <o> Port 5.8 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver
*/
#define IOPDMP58 (0U)

/*
//    <o> Port 5.8 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ EBU.SDCLKO (HWO0)
//       <0x02=> HWI1/ #EBU.CS2 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP58 (2U)
//    </h>

/*
// ---------------- Port 5.9 --------------------------------------------------
// <h> Port5.9
//    <o> Port 5.9 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C0.SELO0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT20 (Alternate Output Function 3)
//       <0x14=> Push-Pull / ETH0.TX_EN (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP59 (0U)

/*
//    <o> Port 5.9 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP59 (0U)

/*
//    <o> Port 5.9 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ EBU.BFCLKO (HWO0)
//       <0x02=> HWI1/ #EBU.CS3 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP59 (2U)
//    </h>

/*
// ---------------- Port 5.10 --------------------------------------------------
// <h> Port5.10
//    <o> Port 5.10 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C0.MCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT10 (Alternate Output Function 3)
//       <0x14=> Push-Pull / LEDTS0.LINE7 (Alternate Output Function 4)
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP510 (16U)

/*
//    <o> Port 5.10 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP510 (0U)

/*
//    <o> Port 5.10 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> LEDTS0.TSIN7A (HWI0)/ LEDTS0.TS7A (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP510 (0U)
//    </h>

/*
// ---------------- Port 5.11 --------------------------------------------------
// <h> Port5.11
//    <o> Port 5.11 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U1C0.SELO1 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU80.OUT00 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP511 (16U)

/*
//    <o> Port 5.11 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP511 (0U)

/*
//    <o> Port 5.11 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP511 (0U)
//    </h>
//    </h>

/*
// ---------------- Port 6 --------------------------------------------------
// <h> Port6
*/

/*
// ---------------- Port 6.0 --------------------------------------------------
// <h> Port6.0
//    <o> Port 6.0 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TXD2 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.SELO1 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU81.OUT31 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP60 (0U)

/*
//    <o> Port 6.0 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP60 (0U)

/*
//    <o> Port 6.0 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DB.ETM_TRACECLK (HWO0)
//       <0x02=> HWI1/ EBU.A16 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP60 (2U)
//    </h>

/*
// ---------------- Port 6.1 --------------------------------------------------
// <h> Port6.1
//    <o> Port 6.1 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TXD3 (Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.SELO0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU81.OUT30 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP61 (0U)

/*
//    <o> Port 6.1 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP61 (0U)

/*
//    <o> Port 6.1 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DB..ETM_TRACEDATA3 (HWO0)
//       <0x02=> HWI1/EBU.A17 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP61 (2U)
//    </h>

/*
// ---------------- Port 6.2 --------------------------------------------------
// <h> Port6.2
//    <o> Port 6.2 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / ETH0.TXER(Alternate Output Function 1)
//       <0x12=> Push-Pull / U0C1.SCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU43.OUT3 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP62 (0U)

/*
//    <o> Port 6.2 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP62 (0U)

/*
//    <o> Port 6.2 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/DB.ETM_TRACEDATA2 (HWO0)
//       <0x02=> HWI1/EBU.A18 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP62 (2U)
//    </h>
/*
// ---------------- Port 6.3 --------------------------------------------------
// <h> Port6.3
//    <o> Port 6.3 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / CCU43.OUT2 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP63 (0U)

/*
//    <o> Port 6.3 Pad Driver Mode Register (A1+)
//       <0x00=> Strong Driver Soft Edge
//       <0x01=> Strong Driver Slow Edge
//       <0x04=> Medium Driver
//       <0x05=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP63 (0U)

/*
//    <o> Port 6.3 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP63 (0U)
//    </h>

/*
// ---------------- Port 6.4 --------------------------------------------------
// <h> Port6.4
//    <o> Port 6.4 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C1.DOUT0 (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU43.OUT1 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP64 (0U)

/*
//    <o> Port 6.4 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Soft Edge
*/
#define IOPDMP64 (0U)

/*
//    <o> Port 6.4 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/EBU.SDCLKO (HWO0)
//       <0x02=> HWI1/EBU.A19 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP64 (2U)
//    </h>

/*
// ---------------- Port 6.5 --------------------------------------------------
// <h> Port6.5
//    <o> Port 6.5 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / U0C1.MCLKOUT (Alternate Output Function 2)
//       <0x13=> Push-Pull / CCU43.OUT0 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP65 (16U)

/*
//    <o> Port 6.5 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP65 (0U)

/*
//    <o> Port 6.5 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DB.ETM_TRACEDATA1 (HWO0)
//       <0x02=> HWI1/ #EBU.BC2 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP65 (0U)
//    </h>

/*
// ---------------- Port 6.6 --------------------------------------------------
// <h> Port6.6
//    <o> Port 6.6 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In
//       <0x10=> Push-Pull / General Purpose Output
//       <0x11=> Push-Pull / Alternate Output Function 1
//       <0x12=> Push-Pull / Alternate Output Function 2
//       <0x13=> Push-Pull / DSD.MCLK3 (Alternate Output Function 3)
//       <0x14=> Push-Pull / Alternate Output Function 4
//       <0x18=> Open Drain / General Purpose Output
//       <0x19=> Open Drain / Alternate Output Function 1
//       <0x1A=> Open Drain / Alternate Output Function 2
//       <0x1B=> Open Drain / Alternate Output Function 3
//       <0x1C=> Open Drain / Alternate Output Function 4

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP66 (16U)

/*
//    <o> Port 6.6 Pad Driver Mode Register (A2)
//       <0x00=> Strong Driver Sharp Edge
//       <0x01=> Strong Driver Medium Edge
//       <0x02=> Strong Driver Soft Edge
//       <0x04=> Medium Driver
//       <0x07=> Weak Driver

//    <i> Defines Pad Driver Configuration
//    <i> Default: Strong Driver Sharp Edge
*/
#define IOPDMP66 (0U)

/*
//    <o> Port 6.6 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DB.ETM_TRACEDATA0 (HWO0)
//       <0x02=> HWI1/ #EBU.BC3 (HWO1)

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP66 (0U)
//    </h>
//    </h>

/*
// <h> Port14
*/

/*
// ---------------- Port 14.0 --------------------------------------------------
// <h> Port14.0
//    <o> Port 14.0 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP140 (0U)

/*
//    <o> Port 14.0 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP140 (0U)
// 		</h>

/*
// ---------------- Port 14.1 --------------------------------------------------
// <h> Port14.1
//    <o> Port 14.1 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP141 (0U)

/*
//    <o> Port 14.1 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP141 (0U)
// 		</h>


/*
// ---------------- Port 14.2 --------------------------------------------------
// <h> Port14.2
//    <o> Port 0.2 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP142 (0U)

/*
//    <o> Port 14.2 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP142 (0U)
// 		</h>

/*
// ---------------- Port 14.3 --------------------------------------------------
// <h> Port14.3
//    <o> Port 14.3 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP143 (0U)

/*
//    <o> Port 14.3 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP143 (0U)
// 		</h>

/*
// ---------------- Port 14.4 --------------------------------------------------
// <h> Port14.4
//    <o> Port 14.4 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP144 (0U)


/*
//    <o> Port 14.4 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP144 (0U)
// 		</h>

/*
// ---------------- Port 14.5 --------------------------------------------------
// <h> Port14.5
//    <o> Port 14.5 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP145 (0U)

/*
//    <o> Port 14.5 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP145 (0U)
// 		</h>

/*
// ---------------- Port 14.6 --------------------------------------------------
// <h> Port14.6
//    <o> Port 14.6 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP146 (0U)

/*
//    <o> Port 14.6 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP146 (0U)
// 		</h>

/*
// ---------------- Port 14.7 --------------------------------------------------
// <h> Port14.7
//    <o> Port 14.7 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP147 (0U)

/*
//    <o> Port 14.7 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP147 (0U)
// 		</h>

/*
// ---------------- Port 14.8 --------------------------------------------------
// <h> Port14.8
//    <o> Port 14.8 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP148 (0U)

/*
//    <o> Port 14.8 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DAC.OUT_0 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP148 (0U)
// 		</h>

/*
// ---------------- Port 14.9 --------------------------------------------------
// <h> Port14.9
//    <o> Port 14.9 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP149 (0U)

/*
//    <o> Port 14.9 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/ DAC.OUT_1 (HWO0)
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP149 (0U)
// 		</h>

/*
// ---------------- Port 14.12 --------------------------------------------------
// <h> Port14.12
//    <o> Port 14.12 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP1412 (0U)

/*
//    <o> Port 14.12 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP1412 (0U)
// 		</h>

/*
// ---------------- Port 14.13 --------------------------------------------------
// <h> Port14.13
//    <o> Port 14.13 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP1413 (0U)

/*
//    <o> Port 14.13 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP1413 (0U)
// 		</h>

/*
// ---------------- Port 14.14 --------------------------------------------------
// <h> Port14.14
//    <o> Port 14.14 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP1414 (0U)

/*
//    <o> Port 14.14 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP1414 (0U)
// 		</h>

/*
// ---------------- Port 14.15 --------------------------------------------------
// <h> Port14.15
//    <o> Port 14.15 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP1415 (0U)

/*
//    <o> Port 14.15 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP1415 (0U)
// 		</h>

//    </h>

/*
// <h> Port15
*/

/*
// ---------------- Port 15.2 --------------------------------------------------
// <h> Port15.2
//    <o> Port 15.2 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP152 (0U)

/*
//    <o> Port 15.2 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP152 (0U)
// 		</h>

/*
// ---------------- Port 15.3 --------------------------------------------------
// <h> Port15.3
//    <o> Port 15.3 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP153 (2U)

/*
//    <o> Port 15.3 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP153 (0U)
// 		</h>

/*
// ---------------- Port 15.4 --------------------------------------------------
// <h> Port15.4
//    <o> Port 15.4 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP154 (2U)


/*
//    <o> Port 15.4 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP154 (0U)
// 		</h>

/*
// ---------------- Port 15.5 --------------------------------------------------
// <h> Port15.5
//    <o> Port 15.5 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP155 (2U)

/*
//    <o> Port 15.5 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP155 (0U)
// 		</h>

/*
// ---------------- Port 15.6 --------------------------------------------------
// <h> Port15.6
//    <o> Port 15.6 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP156 (2U)

/*
//    <o> Port 15.6 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP156 (0U)
// 		</h>

/*
// ---------------- Port 15.7 --------------------------------------------------
// <h> Port15.7
//    <o> Port 15.7 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP157 (2U)

/*
//    <o> Port 15.7 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP157 (0U)
// 		</h>

/*
// ---------------- Port 15.8 --------------------------------------------------
// <h> Port15.8
//    <o> Port 15.8 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP158 (0U)

/*
//    <o> Port 15.8 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP158 (0U)
// 		</h>

/*
// ---------------- Port 15.9 --------------------------------------------------
// <h> Port15.9
//    <o> Port 15.9 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP159 (0U)

/*
//    <o> Port 15.9 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP159 (0U)
// 		</h>

/*
// ---------------- Port 15.12 --------------------------------------------------
// <h> Port15.12
//    <o> Port 15.12 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP1512 (2U)

/*
//    <o> Port 15.12 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP1512 (0U)
// 		</h>

/*
// ---------------- Port 15.13 --------------------------------------------------
// <h> Port15.13
//    <o> Port 15.13 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP1513 (2U)

/*
//    <o> Port 15.13 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP1513 (0U)
// 		</h>

/*
// ---------------- Port 15.14 --------------------------------------------------
// <h> Port15.14
//    <o> Port 15.14 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP1514 (2U)

/*
//    <o> Port 15.14 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP1514 (0U)
// 		</h>

/*
// ---------------- Port 15.15 --------------------------------------------------
// <h> Port15.15
//    <o> Port 15.15 Input/Output Control Register
//       <0x00=> Direct Input / No internal Pull Device
//       <0x01=> Direct Input / Internal Pull Down Device
//       <0x02=> Direct Input / Internal Pull Up Device
//       <0x03=> Direct Input / No Pull Device / Out samples In
//       <0x04=> Inverted Input / No internal Pull Device
//       <0x05=> Inverted Input / Internal Pull Down Device
//       <0x06=> Inverted Input / Internal Pull Up Device
//       <0x07=> Inverted Input / No Pull Device / Out samples In

//    <i> Defines Input/Output Configuration
//    <i> Default: Direct Input / No internal Pull Device
*/
#define IOCRP1515 (2U)

/*
//    <o> Port 15.15 Pin Hardware Select Register 
//       <0x00=> Software Control Only
//       <0x01=> HWI0/HWO0
//       <0x02=> HWI1/HWO1

//    <i> Defines Hardware Select Register
//    <i> Default: Software Control Only
*/
#define IOPHSP1515 (0U)
// 		</h>

//    </h>

/*
//-------- <<< end of configuration section >>> ------------------
*/

/*******************************************************************************
 * API IMPLEMENTATION
 *******************************************************************************/

void MultiplexerInit(void)
{
  /* Port 0 Input/Output Control Register */
	PORT0->IOCR0 = ((IOCRP03  << 27) |
	                (IOCRP02  << 19) |
	                (IOCRP01  << 11) |
	                (IOCRP00  << 3) );  /* IOCR0  */
  PORT0->IOCR4 = ((IOCRP07  << 27) |
	                (IOCRP06  << 19) |
	                (IOCRP05  << 11) |
	                (IOCRP04  << 3) );  /* IOCR4  */
  PORT0->IOCR8 = ((IOCRP011 << 27) |
	                (IOCRP010 << 19) |
	                (IOCRP09  << 11) |
	                (IOCRP08  << 3) );  /* IOCR8  */
  PORT0->IOCR12 =((IOCRP015 << 27) |
	                (IOCRP014 << 19) |
	                (IOCRP013 << 11) |
	                (IOCRP012 << 3) ); /* IOCR12 */
	
	/* Port 0 Pad Driver Mode  Register */
	PORT0->PDR0 = ((IOPDMP07 << 28) |
	               (IOPDMP06 << 24) |
	               (IOPDMP05 << 20) |
	               (IOPDMP04 << 16) |
	               (IOPDMP03 << 12) |
	               (IOPDMP02 <<  8) |
								 (IOPDMP01 <<  4) | 
	               (IOPDMP00     ));          
  PORT0->PDR1 = ((IOPDMP015 << 28) |
	               (IOPDMP014 << 24) |
	               (IOPDMP013 << 20) |
	               (IOPDMP012 << 16) |
	               (IOPDMP011 << 12) |
	               (IOPDMP010 <<  8) |
								 (IOPDMP09  <<  4) | 
	               (IOPDMP08       ));          
  
  /* Port 0 Pin Power Save Register                         */
	PORT0->PPS = 0;                               

  /* Port 0 Pin Hardware Select Register                    */
	PORT0->HWSEL = ((IOPHSP015 << 30) |
                  (IOPHSP014 << 28) |	
                  (IOPHSP013 << 26) |	
                  (IOPHSP012 << 24) |	
                  (IOPHSP011 << 22) |	
                  (IOPHSP010 << 20) |	
                  (IOPHSP09 << 18) |	
                  (IOPHSP08 << 16) |	
                  (IOPHSP07 << 14) |	
                  (IOPHSP06 << 12) |	
                  (IOPHSP05 << 10) |	
                  (IOPHSP04 <<  8) |	
                  (IOPHSP03 <<  6) |	
                  (IOPHSP02 <<  4) |	
                  (IOPHSP01 <<  2) |	
                  (IOPHSP00      ) );	

  /* Port 1 Input/Output Control Register */
	PORT1->IOCR0 = ((IOCRP13  << 27) |
	                (IOCRP12  << 19) |
	                (IOCRP11  << 11) |
	                (IOCRP10  << 3) );  /* IOCR0  */
  PORT1->IOCR4 = ((IOCRP17  << 27) |
	                (IOCRP16  << 19) |
	                (IOCRP15  << 11) |
	                (IOCRP14  << 3) );  /* IOCR4  */
  PORT1->IOCR8 = ((IOCRP111 << 27) |
	                (IOCRP110 << 19) |
	                (IOCRP19  << 11) |
	                (IOCRP18  << 3) );  /* IOCR8  */
  PORT1->IOCR12 =((IOCRP115 << 27) |
	                (IOCRP114 << 19) |
	                (IOCRP113 << 11) |
	                (IOCRP112 << 3) ); /* IOCR12 */
	
	/* Port 1 Pad Driver Mode  Register */
	PORT1->PDR0 = ((IOPDMP17 << 28) |
	               (IOPDMP16 << 24) |
	               (IOPDMP15 << 20) |
	               (IOPDMP14 << 16) |
	               (IOPDMP13 << 12) |
	               (IOPDMP12 <<  8) |
								 (IOPDMP11 <<  4) | 
	               (IOPDMP10     ));          
  PORT1->PDR1 = ((IOPDMP115 << 28) |
	               (IOPDMP114 << 24) |
	               (IOPDMP113 << 20) |
	               (IOPDMP112 << 16) |
	               (IOPDMP111 << 12) |
	               (IOPDMP110 <<  8) |
								 (IOPDMP19  <<  4) | 
	               (IOPDMP18       ));          
  
  /* Port 1 Pin Power Save Register                         */
	PORT1->PPS = 0;                               

  /* Port 1 Pin Hardware Select Register                    */
	PORT1->HWSEL = ((IOPHSP115 << 30) |
                  (IOPHSP114 << 28) |	
                  (IOPHSP113 << 26) |	
                  (IOPHSP112 << 24) |	
                  (IOPHSP111 << 22) |	
                  (IOPHSP110 << 20) |	
                  (IOPHSP19 << 18) |	
                  (IOPHSP18 << 16) |	
                  (IOPHSP17 << 14) |	
                  (IOPHSP16 << 12) |	
                  (IOPHSP15 << 10) |	
                  (IOPHSP14 <<  8) |	
                  (IOPHSP13 <<  6) |	
                  (IOPHSP12 <<  4) |	
                  (IOPHSP11 <<  2) |	
                  (IOPHSP10      ) );	

  /* Port 2 Input/Output Control Register */
	PORT2->IOCR0 = ((IOCRP23  << 27) |
	                (IOCRP22  << 19) |
	                (IOCRP21  << 11) |
	                (IOCRP20  << 3) );  /* IOCR0  */
  PORT2->IOCR4 = ((IOCRP27  << 27) |
	                (IOCRP26  << 19) |
	                (IOCRP25  << 11) |
	                (IOCRP24  << 3) );  /* IOCR4  */
  PORT2->IOCR8 = ((IOCRP211 << 27) |
	                (IOCRP210 << 19) |
	                (IOCRP29  << 11) |
	                (IOCRP28  << 3) );  /* IOCR8  */
  PORT2->IOCR12 =((IOCRP215 << 27) |
	                (IOCRP214 << 19) |
	                (IOCRP213 << 11) |
	                (IOCRP212 << 3) ); /* IOCR12 */
	
	/* Port 2 Pad Driver Mode  Register */
	PORT2->PDR0 = ((IOPDMP27 << 28) |
	               (IOPDMP26 << 24) |
	               (IOPDMP25 << 20) |
	               (IOPDMP24 << 16) |
	               (IOPDMP23 << 12) |
	               (IOPDMP22 <<  8) |
								 (IOPDMP21 <<  4) | 
	               (IOPDMP20     ));          
  PORT2->PDR1 = ((IOPDMP215 << 28) |
	               (IOPDMP214 << 24) |
	               (IOPDMP213 << 20) |
	               (IOPDMP212 << 16) |
	               (IOPDMP211 << 12) |
	               (IOPDMP210 <<  8) |
								 (IOPDMP29  <<  4) | 
	               (IOPDMP28       ));          
  
  /* Port 2 Pin Power Save Register                         */
	PORT2->PPS = 0;                               

  /* Port 2 Pin Hardware Select Register                    */
	PORT2->HWSEL = ((IOPHSP215 << 30) |
                  (IOPHSP214 << 28) |	
                  (IOPHSP213 << 26) |	
                  (IOPHSP212 << 24) |	
                  (IOPHSP211 << 22) |	
                  (IOPHSP210 << 20) |	
                  (IOPHSP29 << 18) |	
                  (IOPHSP28 << 16) |	
                  (IOPHSP27 << 14) |	
                  (IOPHSP26 << 12) |	
                  (IOPHSP25 << 10) |	
                  (IOPHSP24 <<  8) |	
                  (IOPHSP23 <<  6) |	
                  (IOPHSP22 <<  4) |	
                  (IOPHSP21 <<  2) |	
                  (IOPHSP20      ) );	

  /* Port 3 Input/Output Control Register */
	PORT3->IOCR0 = ((IOCRP33  << 27) |
	                (IOCRP32  << 19) |
	                (IOCRP31  << 11) |
	                (IOCRP30  << 3) );  /* IOCR0  */
  PORT3->IOCR4 = ((IOCRP37  << 27) |
	                (IOCRP36  << 19) |
	                (IOCRP35  << 11) |
	                (IOCRP34  << 3) );  /* IOCR4  */
  PORT3->IOCR8 = ((IOCRP311 << 27) |
	                (IOCRP310 << 19) |
	                (IOCRP39  << 11) |
	                (IOCRP38  << 3) );  /* IOCR8  */
  PORT3->IOCR12 =((IOCRP315 << 27) |
	                (IOCRP314 << 19) |
	                (IOCRP313 << 11) |
	                (IOCRP312 << 3) ); /* IOCR12 */
	
	/* Port 3 Pad Driver Mode  Register */
	PORT3->PDR0 = ((IOPDMP37 << 28) |
	               (IOPDMP36 << 24) |
	               (IOPDMP35 << 20) |
	               (IOPDMP34 << 16) |
	               (IOPDMP33 << 12) |
	               (IOPDMP32 <<  8) |
								 (IOPDMP31 <<  4) | 
	               (IOPDMP30     ));          
  PORT3->PDR1 = ((IOPDMP315 << 28) |
	               (IOPDMP314 << 24) |
	               (IOPDMP313 << 20) |
	               (IOPDMP312 << 16) |
	               (IOPDMP311 << 12) |
	               (IOPDMP310 <<  8) |
								 (IOPDMP39  <<  4) | 
	               (IOPDMP38       ));          
  
  /* Port 3 Pin Power Save Register                         */
	PORT3->PPS = 0;                               

  /* Port 3 Pin Hardware Select Register                    */
	PORT3->HWSEL = ((IOPHSP315 << 30) |
                  (IOPHSP314 << 28) |	
                  (IOPHSP313 << 26) |	
                  (IOPHSP312 << 24) |	
                  (IOPHSP311 << 22) |	
                  (IOPHSP310 << 20) |	
                  (IOPHSP39 << 18) |	
                  (IOPHSP38 << 16) |	
                  (IOPHSP37 << 14) |	
                  (IOPHSP36 << 12) |	
                  (IOPHSP35 << 10) |	
                  (IOPHSP34 <<  8) |	
                  (IOPHSP33 <<  6) |	
                  (IOPHSP32 <<  4) |	
                  (IOPHSP31 <<  2) |	
                  (IOPHSP30      ) );	

  /* Port 4 Input/Output Control Register */
	PORT4->IOCR0 = ((IOCRP43  << 27) |
	                (IOCRP42  << 19) |
	                (IOCRP41  << 11) |
	                (IOCRP40  << 3) );  /* IOCR0  */
  PORT4->IOCR4 = ((IOCRP47  << 27) |
	                (IOCRP46  << 19) |
	                (IOCRP45  << 11) |
	                (IOCRP44  << 3) );  /* IOCR4  */
	
	/* Port 4 Pad Driver Mode  Register */
	PORT4->PDR0 = ((IOPDMP47 << 28) |
	               (IOPDMP46 << 24) |
	               (IOPDMP45 << 20) |
	               (IOPDMP44 << 16) |
	               (IOPDMP43 << 12) |
	               (IOPDMP42 <<  8) |
								 (IOPDMP41 <<  4) | 
	               (IOPDMP40     ));          
  
  /* Port 4 Pin Power Save Register                         */
	PORT4->PPS = 0;                               

  /* Port 4 Pin Hardware Select Register                    */
	PORT4->HWSEL = ((IOPHSP47 << 14) |	
                  (IOPHSP46 << 12) |	
                  (IOPHSP45 << 10) |	
                  (IOPHSP44 <<  8) |	
                  (IOPHSP43 <<  6) |	
                  (IOPHSP42 <<  4) |	
                  (IOPHSP41 <<  2) |	
                  (IOPHSP40      ) );	

  /* Port 5 Input/Output Control Register */
	PORT5->IOCR0 = ((IOCRP53  << 27) |
	                (IOCRP52  << 19) |
	                (IOCRP51  << 11) |
	                (IOCRP50  << 3) );  /* IOCR0  */
  PORT5->IOCR4 = ((IOCRP57  << 27) |
	                (IOCRP56  << 19) |
	                (IOCRP55  << 11) |
	                (IOCRP54  << 3) );  /* IOCR4  */
  PORT5->IOCR8 = ((IOCRP511 << 27) |
	                (IOCRP510 << 19) |
	                (IOCRP59  << 11) |
	                (IOCRP58  << 3) );  /* IOCR8  */
	
	/* Port 5 Pad Driver Mode  Register */
	PORT5->PDR0 = ((IOPDMP57 << 28) |
	               (IOPDMP56 << 24) |
	               (IOPDMP55 << 20) |
	               (IOPDMP54 << 16) |
	               (IOPDMP53 << 12) |
	               (IOPDMP52 <<  8) |
								 (IOPDMP51 <<  4) | 
	               (IOPDMP50     ));          
  PORT5->PDR1 = ((IOPDMP511 << 12) |
	               (IOPDMP510 <<  8) |
								 (IOPDMP59  <<  4) | 
	               (IOPDMP58       ));          
  
  /* Port 5 Pin Power Save Register                         */
	PORT5->PPS = 0;                               

  /* Port 5 Pin Hardware Select Register                    */
	PORT5->HWSEL = ((IOPHSP511 << 22) |	
                  (IOPHSP510 << 20) |	
                  (IOPHSP59 << 18) |	
                  (IOPHSP58 << 16) |	
                  (IOPHSP57 << 14) |	
                  (IOPHSP56 << 12) |	
                  (IOPHSP55 << 10) |	
                  (IOPHSP54 <<  8) |	
                  (IOPHSP53 <<  6) |	
                  (IOPHSP52 <<  4) |	
                  (IOPHSP51 <<  2) |	
                  (IOPHSP50      ) );	

/* Port 6 Input/Output Control Register */
	PORT6->IOCR0 = ((IOCRP63  << 27) |
	                (IOCRP62  << 19) |
	                (IOCRP61  << 11) |
	                (IOCRP60  << 3) );  /* IOCR0  */
  PORT6->IOCR4 = ((IOCRP66  << 19) |
	                (IOCRP65  << 11) |
	                (IOCRP64  << 3) );  /* IOCR4  */
	
	/* Port 6 Pad Driver Mode  Register */
	PORT6->PDR0 = ((IOPDMP66 << 24) |
	               (IOPDMP65 << 20) |
	               (IOPDMP64 << 16) |
	               (IOPDMP63 << 12) |
	               (IOPDMP62 <<  8) |
								 (IOPDMP61 <<  4) | 
	               (IOPDMP60     ));          
  
  /* Port 6 Pin Power Save Register                         */
	PORT6->PPS = 0;                               

  /* Port 6 Pin Hardware Select Register                    */
	PORT6->HWSEL = ((IOPHSP66 << 12) |	
                  (IOPHSP65 << 10) |	
                  (IOPHSP64 <<  8) |	
                  (IOPHSP63 <<  6) |	
                  (IOPHSP62 <<  4) |	
                  (IOPHSP61 <<  2) |	
                  (IOPHSP60      ) );	

  /* Port 14 Input/Output Control Register */
	PORT14->IOCR0 = ((IOCRP143  << 27) |
	                 (IOCRP142  << 19) |
	                 (IOCRP141  << 11) |
	                 (IOCRP140  << 3) );  /* IOCR0  */
  PORT14->IOCR4 = ((IOCRP147  << 27) |
	                 (IOCRP146  << 19) |
	                 (IOCRP145  << 11) |
	                 (IOCRP144  << 3) );  /* IOCR4  */
  PORT14->IOCR8 = ((IOCRP149  << 11) |
	                 (IOCRP148  << 3) );  /* IOCR8  */
  PORT14->IOCR12 =((IOCRP1415 << 27) |
	                 (IOCRP1414 << 19) |
	                 (IOCRP1413 << 11) |
	                 (IOCRP1412 << 3) ); /* IOCR12 */
	  
  /* Port 14 Pin Power Save Register                         */
	PORT14->PPS = 0;                               

  /* Port 14 Pin Hardware Select Register                    */
	PORT14->HWSEL = ((IOPHSP1415 << 30) |
                   (IOPHSP1414 << 28) |	
                   (IOPHSP1413 << 26) |	
                   (IOPHSP1412 << 24) |	
                   (IOPHSP149 << 18) |	
                   (IOPHSP148 << 16) |	
                   (IOPHSP147 << 14) |	
                   (IOPHSP146 << 12) |	
                   (IOPHSP145 << 10) |	
                   (IOPHSP144 <<  8) |	
                   (IOPHSP143 <<  6) |	
                   (IOPHSP142 <<  4) |	
                   (IOPHSP141 <<  2) |	
                   (IOPHSP140      ) );

  PORT14->PDISC = 0x0000;   // Alle Digital Pad Inputs am P14 einschalten

  /* Port 15 Input/Output Control Register */
	PORT15->IOCR0 = ((IOCRP153  << 27) |
	                 (IOCRP152  << 19) );  /* IOCR0  */
  PORT15->IOCR4 = ((IOCRP157  << 27) |
	                 (IOCRP156  << 19) |
	                 (IOCRP155  << 11) |
	                 (IOCRP154  << 3) );  /* IOCR4  */
  PORT15->IOCR8 = ((IOCRP159  << 11) |
	                 (IOCRP158  << 3) );  /* IOCR8  */
  PORT15->IOCR12 =((IOCRP1515 << 27) |
	                 (IOCRP1514 << 19) |
	                 (IOCRP1513 << 11) |
	                 (IOCRP1512 << 3) ); /* IOCR12 */
	  
  /* Port 15 Pin Power Save Register                         */
	PORT15->PPS = 0;                               

  /* Port 15 Pin Hardware Select Register                    */
	PORT15->HWSEL = ((IOPHSP1515 << 30) |
                   (IOPHSP1514 << 28) |	
                   (IOPHSP1513 << 26) |	
                   (IOPHSP1512 << 24) |	
                   (IOPHSP159 << 18) |	
                   (IOPHSP158 << 16) |	
                   (IOPHSP157 << 14) |	
                   (IOPHSP156 << 12) |	
                   (IOPHSP155 << 10) |	
                   (IOPHSP154 <<  8) |	
                   (IOPHSP153 <<  6) |	
                   (IOPHSP152 <<  4)  );	

  PORT15->PDISC = 0x0000;   // Alle Digital Pad Inputs am P15 einschalten

}

